@@ -156,6 +156,10 @@ intPGOcc <- function(occ.formula, det.formula, data, inits, priors,
     if (n.thin > n.samples) {
       stop("error: n.thin must be less than n.samples")
     }
+    # Check if n.burn, n.thin, and n.samples result in an integer and error if otherwise.
+    if (((n.samples - n.burn) / n.thin) %% 1 != 0) {
+      stop("the number of posterior samples to save ((n.samples - n.burn) / n.thin) is not a whole number. Please respecify the MCMC criteria such that the number of posterior samples saved is a whole number.")
+    }
     if (!missing(k.fold)) {
       if (!is.numeric(k.fold) | length(k.fold) != 1 | k.fold < 2) {
         stop("error: k.fold must be a single integer value >= 2")  
@@ -527,10 +531,10 @@ intPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       if (n.chains > 1) {
         out$rhat$beta <- gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
         					      mcmc(t(a$beta.samples)))), 
-        			     autoburnin = FALSE)$psrf[, 2]
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2]
         out$rhat$alpha <- gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
         					      mcmc(t(a$alpha.samples)))), 
-        			      autoburnin = FALSE)$psrf[, 2]
+        			      autoburnin = FALSE, multivariate = FALSE)$psrf[, 2]
       } else {
         out$rhat$beta <- rep(NA, p.occ)
         out$rhat$alpha <- rep(NA, p.det)
@@ -762,7 +766,7 @@ intPGOcc <- function(occ.formula, det.formula, data, inits, priors,
     class(out) <- "intPGOcc"
 
     out$run.time <- proc.time() - ptm
-    # TODO: 
+    # TODO: add in random effects eventually
     out$pRE <- FALSE
     out$psiRE <- FALSE
     out
