@@ -87,10 +87,25 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
   if (!is.list(data$det.covs)) {
     stop("error: det.covs must be a list of matrices, data frames, and/or vectors")
   }
+  # Check grid index
+  if (!'grid.index' %in% names(data)) {
+    if (nrow(data$coords) != nrow(data$y)) {
+      stop("data$grid.index must be specified if nrow(data$coords) != nrow(data$y)")
+    }
+    grid.index <- 1:nrow(coords)
+  } else {
+    if (!is.atomic(data$grid.index) | !is.numeric(data$grid.index)) {
+      stop("data$grid.index must be a numeric vector")
+    }
+    if (length(data$grid.index) < nrow(data$coords)) {
+      stop("length(data$grid.index) must be greater than or equal to nrow(data$coords)")
+    }
+    grid.index <- data$grid.index
+  }
   # Check if all spatial coordinates are unique. 
   unique.coords <- unique(data$coords)
   if (nrow(unique.coords) < nrow(data$coords)) {
-    stop("coordinates provided in coords are not all unique. spOccupancy requires each site to have its own unique pair of spatial coordinates. This may be the result of an error in preparing the data list, or you will need to change what you consider a 'site' in order to meet this requirement.") 
+    stop("coordinates provided in coords are not all unique. spOccupancy requires each site to have its own unique pair of spatial coordinates. This may be the result of an error in preparing the data list, or you will need to change what you consider a 'site' in order to meet this requirement. Alternatively, you can use data$grid.index to specify the spatial random effect at a larger spatial level than the individual sites (e.g., a grid). See ?spPGOcc for details.") 
   }
   if (!missing(k.fold)) {
     if (!is.numeric(k.fold) | length(k.fold) != 1 | k.fold < 2) {
@@ -104,16 +119,21 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
     u.search.type <- 2 
     ## Order by x column. Could potentially allow this to be user defined. 
     ord <- order(coords[,1]) 
+    tmp <- lapply(ord, function (a) which(grid.index == a))
+    tmp.2 <- sapply(tmp, length)
+    grid.index.c <- unlist(lapply(1:length(tmp.2), function(a) rep(a, tmp.2[a]))) - 1
+    grid.index.r <- grid.index.c + 1
+    long.ord <- unlist(lapply(ord, function(a) which(grid.index == a)))
     # Reorder everything to align with NN ordering
-    y <- y[ord, , drop = FALSE]
+    y <- y[long.ord, , drop = FALSE]
     coords <- coords[ord, , drop = FALSE]
     # Occupancy covariates
-    data$occ.covs <- data$occ.covs[ord, , drop = FALSE]
+    data$occ.covs <- data$occ.covs[long.ord, , drop = FALSE]
     for (i in 1:length(data$det.covs)) {
       if (!is.null(dim(data$det.covs[[i]]))) {
-        data$det.covs[[i]] <- data$det.covs[[i]][ord, , drop = FALSE]
+        data$det.covs[[i]] <- data$det.covs[[i]][long.ord, , drop = FALSE]
       } else {
-        data$det.covs[[i]] <- data$det.covs[[i]][ord]
+        data$det.covs[[i]] <- data$det.covs[[i]][long.ord]
       }
     }
   }
@@ -233,6 +253,8 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
   # Get basic info from inputs ------------------------------------------
   # Number of sites
   J <- nrow(y.big)
+  # Number of coordinates in coordinate grid
+  J.w <- nrow(coords)
   # Number of occupancy parameters 
   p.occ <- ncol(X)
   # Number of detection parameters
@@ -271,7 +293,10 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
   if (n.thin > n.samples) {
     stop("error: n.thin must be less than n.samples")
   }
-
+  # Check if n.burn, n.thin, and n.samples result in an integer and error if otherwise.
+  if (((n.samples - n.burn) / n.thin) %% 1 != 0) {
+    stop("the number of posterior samples to save ((n.samples - n.burn) / n.thin) is not a whole number. Please respecify the MCMC criteria such that the number of posterior samples saved is a whole number.")
+  }
   # Get indices to map z to y -------------------------------------------
   if (!binom) {
     z.long.indx <- rep(1:J, dim(y.big)[2])
@@ -625,7 +650,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
     }
     # Reorder the user supplied inits values
     if (NNGP) {
-      z.inits <- z.inits[ord]
+      z.inits <- z.inits[long.ord]
     }
     z.test <- apply(y.big, 1, max, na.rm = TRUE)
     init.test <- sum(z.inits < z.test)
@@ -715,14 +740,18 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
     w.inits <- inits[["w"]]
     if (!is.vector(w.inits)) {
       stop(paste("error: initial values for w must be a vector of length ",
-      	   J, sep = ""))
+      	   J.w, sep = ""))
     }
-    if (length(w.inits) != J) {
+    if (length(w.inits) != J.w) {
       stop(paste("error: initial values for w must be a vector of length ",
-      	   J, sep = ""))
+      	   J.w, sep = ""))
+    }
+    # Reorder the user supplied inits values
+    if (NNGP) {
+      w.inits <- w.inits[ord]
     }
   } else {
-    w.inits <- rep(0, J)
+    w.inits <- rep(0, J.w)
     if (verbose) {
       message("w is not specified in initial values.\nSetting initial value to 0\n")
     }
@@ -874,7 +903,9 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
   curr.chain <- 1
 
   if (!NNGP) {
-
+    if (J.w != J) {
+      stop("data$grid.index is not currently supported when NNGP = FALSE. If specifying the spatial random effect across a grid that is different from the individual site locations, please set NNGP = TRUE.")
+    }
     # Set storage for all variables ---------------------------------------
     storage.mode(y) <- "double"
     storage.mode(z.inits) <- "double"
@@ -1006,56 +1037,24 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       out$rhat <- list()
       if (n.chains > 1) {
         # as.vector removes the "Upper CI" when there is only 1 variable. 
-        if (!fixed.params[which(all.params == 'beta')]) {
-          out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-          					         mcmc(t(a$beta.samples)))), 
-          			     autoburnin = FALSE)$psrf[, 2])
-        } else {
-          out$rhat$beta <- rep(NA, p.occ)
-        }
-        if (!fixed.params[which(all.params == 'alpha')]) {
+        out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
+        					         mcmc(t(a$beta.samples)))), 
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         out$rhat$alpha <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
         					      mcmc(t(a$alpha.samples)))), 
-        			      autoburnin = FALSE)$psrf[, 2])
-        } else {
-          out$rhat$alpha <- rep(NA, p.det)
-        }
-        if (!fixed.params[which(all.params == 'sigma.sq')] & 
-            !fixed.params[which(all.params == 'phi')]) { # none are fixed
+        			      autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
           out$rhat$theta <- gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
         					        mcmc(t(a$theta.samples)))), 
-        			      autoburnin = FALSE)$psrf[, 2]
-        } else if (fixed.params[which(all.params == 'sigma.sq')] & 
-          	 !fixed.params[which(all.params == 'phi')]) { # sigma.sq is fixed
-          out$rhat$theta <- c(NA, gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					        mcmc(t(a$theta.samples[-1, , drop = FALSE])))), 
-        			      autoburnin = FALSE)$psrf[, 2])
-        } else if (!fixed.params[which(all.params == 'sigma.sq')] & 
-          	 fixed.params[which(all.params == 'phi')]) { # phi/nu is fixed
-          tmp <- ifelse(cov.model == 'matern', NA, c(NA, NA))
-          out$rhat$theta <- c(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					        mcmc(t(a$theta.samples[1, , drop = FALSE])))), 
-        			      autoburnin = FALSE)$psrf[, 2], tmp)
-        } else { # both are fixed
-          out$rhat$theta <- rep(NA, ifelse(cov.model == 'matern', 3, 2))
-        } 
+        			      autoburnin = FALSE, multivariate = FALSE)$psrf[, 2]
         if (p.det.re > 0) {
-          if (!fixed.params[which(all.params == 'sigma.sq.p')]) {
             out$rhat$sigma.sq.p <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
             					       mcmc(t(a$sigma.sq.p.samples)))), 
-            			           autoburnin = FALSE)$psrf[, 2])
-          } else {
-            out$rhat$sigma.sq.p <- rep(NA, p.det.re)
-          }
+            			           autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         }
         if (p.occ.re > 0) {
-          if (!fixed.params[which(all.params == 'sigma.sq.psi')]) {
             out$rhat$sigma.sq.psi <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
           					         mcmc(t(a$sigma.sq.psi.samples)))), 
-          			             autoburnin = FALSE)$psrf[, 2])
-          } else {
-            out$rhat$sigma.sq.psi <- rep(NA, p.occ.re)
-          }
+          			             autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         }
       } else {
         out$rhat$beta <- rep(NA, p.occ)
@@ -1409,6 +1408,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
     storage.mode(nn.indx.lu) <- "integer"
     storage.mode(u.search.type) <- "integer"
     storage.mode(J) <- "integer"
+    storage.mode(J.w) <- "integer"
 
     if(verbose){
       cat("----------------------------------------\n");
@@ -1416,7 +1416,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       cat("----------------------------------------\n");
     }
     
-    indx <- mkUIndx(J, n.neighbors, nn.indx, nn.indx.lu, u.search.type)
+    indx <- mkUIndx(J.w, n.neighbors, nn.indx, nn.indx.lu, u.search.type)
     
     u.indx <- indx$u.indx
     u.indx.lu <- indx$u.indx.lu
@@ -1428,8 +1428,9 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
     storage.mode(z.inits) <- "double"
     storage.mode(X.p) <- "double"
     storage.mode(X) <- "double"
-    consts <- c(J, n.obs, p.occ, p.occ.re, n.occ.re, p.det, p.det.re, n.det.re)
+    consts <- c(J, n.obs, p.occ, p.occ.re, n.occ.re, p.det, p.det.re, n.det.re, J.w)
     storage.mode(consts) <- "integer"
+    storage.mode(grid.index.c) <- "integer"
     storage.mode(K) <- "double"
     storage.mode(coords) <- "double"
     storage.mode(beta.inits) <- "double"
@@ -1550,7 +1551,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         	                    tuning.c, cov.model.indx,
                               n.batch, batch.length, 
                               accept.rate, n.omp.threads, verbose, n.report, 
-                              samples.info, chain.info, fixed.params, sigma.sq.ig)
+                              samples.info, chain.info, fixed.params, sigma.sq.ig, grid.index.c)
         chain.info[1] <- chain.info[1] + 1
       }
       # Calculate R-Hat ---------------
@@ -1558,56 +1559,24 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       out$rhat <- list()
       if (n.chains > 1) {
         # as.vector removes the "Upper CI" when there is only 1 variable. 
-        if (!fixed.params[which(all.params == 'beta')]) {
-          out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-          					         mcmc(t(a$beta.samples)))), 
-          			     autoburnin = FALSE)$psrf[, 2])
-        } else {
-          out$rhat$beta <- rep(NA, p.occ)
-        }
-        if (!fixed.params[which(all.params == 'alpha')]) {
+        out$rhat$beta <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
+        					         mcmc(t(a$beta.samples)))), 
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         out$rhat$alpha <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
         					      mcmc(t(a$alpha.samples)))), 
-        			      autoburnin = FALSE)$psrf[, 2])
-        } else {
-          out$rhat$alpha <- rep(NA, p.det)
-        }
-        if (!fixed.params[which(all.params == 'sigma.sq')] & 
-            !fixed.params[which(all.params == 'phi')]) { # none are fixed
+        			      autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
           out$rhat$theta <- gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
         					        mcmc(t(a$theta.samples)))), 
-        			      autoburnin = FALSE)$psrf[, 2]
-        } else if (fixed.params[which(all.params == 'sigma.sq')] & 
-          	 !fixed.params[which(all.params == 'phi')]) { # sigma.sq is fixed
-          out$rhat$theta <- c(NA, gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					        mcmc(t(a$theta.samples[-1, , drop = FALSE])))), 
-        			      autoburnin = FALSE)$psrf[, 2])
-        } else if (!fixed.params[which(all.params == 'sigma.sq')] & 
-          	 fixed.params[which(all.params == 'phi')]) { # phi/nu is fixed
-          tmp <- ifelse(cov.model == 'matern', NA, c(NA, NA))
-          out$rhat$theta <- c(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
-        					        mcmc(t(a$theta.samples[1, , drop = FALSE])))), 
-        			      autoburnin = FALSE)$psrf[, 2], tmp)
-        } else { # both are fixed
-          out$rhat$theta <- rep(NA, ifelse(cov.model == 'matern', 3, 2))
-        } 
+        			      autoburnin = FALSE, multivariate = FALSE)$psrf[, 2]
         if (p.det.re > 0) {
-          if (!fixed.params[which(all.params == 'sigma.sq.p')]) {
             out$rhat$sigma.sq.p <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
             					       mcmc(t(a$sigma.sq.p.samples)))), 
-            			           autoburnin = FALSE)$psrf[, 2])
-          } else {
-            out$rhat$sigma.sq.p <- rep(NA, p.det.re)
-          }
+            			           autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         }
         if (p.occ.re > 0) {
-          if (!fixed.params[which(all.params == 'sigma.sq.psi')]) {
             out$rhat$sigma.sq.psi <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
           					         mcmc(t(a$sigma.sq.psi.samples)))), 
-          			             autoburnin = FALSE)$psrf[, 2])
-          } else {
-            out$rhat$sigma.sq.psi <- rep(NA, p.occ.re)
-          }
+          			             autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         }
       } else {
         out$rhat$beta <- rep(NA, p.occ)
@@ -1634,37 +1603,37 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       # Get everything back in the original order
       out$coords <- coords[order(ord), ]
       out$z.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$z.samples))))
-      out$z.samples <- mcmc(out$z.samples[, order(ord), drop = FALSE])
-      out$X <- X[order(ord), , drop = FALSE]
-      out$X.re <- X.re[order(ord), , drop = FALSE]
+      out$z.samples <- mcmc(out$z.samples[, order(long.ord), drop = FALSE])
+      out$X <- X[order(long.ord), , drop = FALSE]
+      out$X.re <- X.re[order(long.ord), , drop = FALSE]
       out$w.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$w.samples))))
       out$w.samples <- mcmc(out$w.samples[, order(ord), drop = FALSE])
       out$psi.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$psi.samples))))
-      out$psi.samples <- mcmc(out$psi.samples[, order(ord), drop = FALSE])
+      out$psi.samples <- mcmc(out$psi.samples[, order(long.ord), drop = FALSE])
       out$like.samples <- mcmc(do.call(rbind, lapply(out.tmp, function(a) t(a$like.samples))))
-      out$like.samples <- mcmc(out$like.samples[, order(ord), drop = FALSE])
+      out$like.samples <- mcmc(out$like.samples[, order(long.ord), drop = FALSE])
       # Get detection covariate stuff in right order. Method of doing this
       # depends on if there are observation level covariates or not. 
       if (!binom) {
         tmp <- matrix(NA, J * K.max, p.det)
         tmp[names.long, ] <- X.p
         tmp <- array(tmp, dim = c(J, K.max, p.det))
-        tmp <- tmp[order(ord), , ]
+        tmp <- tmp[order(long.ord), , ]
         out$X.p <- matrix(tmp, J * K.max, p.det)
         out$X.p <- out$X.p[apply(out$X.p, 1, function(a) sum(is.na(a))) == 0, , drop = FALSE]
         colnames(out$X.p) <- x.p.names
         tmp <- matrix(NA, J * K.max, p.det.re)
         tmp[names.long, ] <- X.p.re
         tmp <- array(tmp, dim = c(J, K.max, p.det.re))
-        tmp <- tmp[order(ord), , ]
+        tmp <- tmp[order(long.ord), , ]
         out$X.p.re <- matrix(tmp, J * K.max, p.det.re)
         out$X.p.re <- out$X.p.re[apply(out$X.p.re, 1, function(a) sum(is.na(a))) == 0, , drop = FALSE]
         colnames(out$X.p.re) <- x.p.re.names
       } else {
-        out$X.p <- X.p[order(ord), , drop = FALSE]
-        out$X.p.re <- X.p.re[order(ord), , drop = FALSE]
+        out$X.p <- X.p[order(long.ord), , drop = FALSE]
+        out$X.p.re <- X.p.re[order(long.ord), , drop = FALSE]
       }
-      out$y <- y.big[order(ord), , drop = FALSE]
+      out$y <- y.big[order(long.ord), , drop = FALSE]
       if (p.occ.re > 0) {
         out$sigma.sq.psi.samples <- mcmc(
           do.call(rbind, lapply(out.tmp, function(a) t(a$sigma.sq.psi.samples))))
@@ -1729,11 +1698,12 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       }
       set.seed(k.fold.seed)
       # Number of sites in each hold out data set. 
-      sites.random <- sample(1:J)    
+      sites.random <- sample(1:J.w)    
       sites.k.fold <- split(sites.random, sites.random %% k.fold)
       registerDoParallel(k.fold.threads)
       model.deviance <- foreach (i = 1:k.fold, .combine = sum) %dopar% {
-        curr.set <- sort(sites.random[sites.k.fold[[i]]])
+        curr.set.small <- sort(sites.random[sites.k.fold[[i]]])
+        curr.set <- which(grid.index.r %in% curr.set.small)
         if (binom) {
           y.indx <- !(1:J %in% curr.set)
         } else {
@@ -1750,8 +1720,21 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
 	X.0 <- X[curr.set, , drop = FALSE]
 	J.fit <- nrow(X.fit)
 	J.0 <- nrow(X.0)
-        coords.fit <- coords[-curr.set, , drop = FALSE]
-        coords.0 <- coords[curr.set, , drop = FALSE]
+        coords.fit <- coords[-curr.set.small, , drop = FALSE]
+        coords.0 <- coords[curr.set.small, , drop = FALSE]
+	J.w.fit <- nrow(coords.fit)
+        tmp.grid.fit <- grid.index.r[-curr.set]
+        tmp.grid.0 <- grid.index.r[curr.set]
+        # Reorder the grids to get their indices to work
+        grid.fit <- vector('numeric', length = length(tmp.grid.fit))
+        for (j in 1:nrow(coords.fit)) {
+          grid.fit[which(tmp.grid.fit == (1:J.w)[-curr.set.small][j])] <- j
+        }
+        grid.0 <- vector('numeric', length = length(tmp.grid.0))
+        for (j in 1:nrow(coords.0)) {
+          grid.0[which(tmp.grid.0 == curr.set.small[j])] <- j
+        }
+	grid.fit.c <- grid.fit - 1
 	K.fit <- K[-curr.set]
 	K.0 <- K[curr.set]
 	rep.indx.fit <- rep.indx[-curr.set]
@@ -1824,7 +1807,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         nn.indx.fit <- indx$nnIndx
         nn.indx.lu.fit <- indx$nnIndxLU
         
-        indx <- mkUIndx(J.fit, n.neighbors, nn.indx.fit, 
+        indx <- mkUIndx(J.w.fit, n.neighbors, nn.indx.fit, 
       		  nn.indx.lu.fit, u.search.type)
         
         u.indx.fit <- indx$u.indx
@@ -1838,7 +1821,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         storage.mode(coords.fit) <- "double"
         storage.mode(K.fit) <- "double"
         consts.fit <- c(J.fit, n.obs.fit, p.occ, p.occ.re, n.occ.re.fit, 
-                        p.det, p.det.re, n.det.re.fit)
+                        p.det, p.det.re, n.det.re.fit, J.w.fit)
         storage.mode(consts.fit) <- "integer"
         storage.mode(z.long.indx.fit) <- "integer"
         storage.mode(nn.indx.fit) <- "integer"
@@ -1862,6 +1845,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         storage.mode(beta.level.indx.fit) <- "integer"
         chain.info[1] <- 1
         storage.mode(chain.info) <- "integer"
+	storage.mode(grid.fit.c) <- 'integer'
         # Run the model in C
         out.fit <- .Call("spPGOccNNGP", y.fit, X.fit, X.p.fit, coords.fit, X.re.fit, X.p.re.fit, 
 			 consts.fit, K.fit, n.occ.re.long.fit, n.det.re.long.fit, 
@@ -1875,7 +1859,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
 			 sigma.sq.a, sigma.sq.b, nu.a, nu.b, sigma.sq.psi.a, sigma.sq.psi.b, 
 			 sigma.sq.p.a, sigma.sq.p.b, tuning.c, cov.model.indx, 
 			 n.batch, batch.length, accept.rate, n.omp.threads.fit, verbose.fit, 
-			 n.report, samples.info, chain.info, fixed.params, sigma.sq.ig)
+			 n.report, samples.info, chain.info, fixed.params, sigma.sq.ig, grid.fit.c)
         out.fit$beta.samples <- mcmc(t(out.fit$beta.samples))
         colnames(out.fit$beta.samples) <- x.names
         out.fit$alpha.samples <- mcmc(t(out.fit$alpha.samples))
@@ -1940,7 +1924,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
 	}
 	# Predict occurrence at new sites
         if (p.occ.re > 0) {X.0 <- cbind(X.0, X.re.0)}
-        out.pred <- predict.spPGOcc(out.fit, X.0, coords.0, verbose = FALSE)
+        out.pred <- predict.spPGOcc(out.fit, X.0, coords.0, verbose = FALSE, grid.index.0 = grid.0)
 
 	# Detection 
         # Generate detection values
