@@ -193,7 +193,10 @@ svcTPGBinom <- function(formula, data, inits, priors,
   if (n.thin > n.samples) {
     stop("error: n.thin must be less than n.samples")
   }
-
+  # Check if n.burn, n.thin, and n.samples result in an integer and error if otherwise.
+  if (((n.samples - n.burn) / n.thin) %% 1 != 0) {
+    stop("the number of posterior samples to save ((n.samples - n.burn) / n.thin) is not a whole number. Please respecify the MCMC criteria such that the number of posterior samples saved is a whole number.")
+  }
   # Check SVC columns -----------------------------------------------------
   if (is.character(svc.cols)) {
     # Check if all column names in svc are in covs
@@ -917,14 +920,14 @@ svcTPGBinom <- function(formula, data, inits, priors,
       if (n.chains > 1) {
         out$rhat$beta <- gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
         					      mcmc(t(a$beta.samples)))), 
-        			     autoburnin = FALSE)$psrf[, 2]
+        			     autoburnin = FALSE, multivariate = FALSE)$psrf[, 2]
         out$rhat$theta <- gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
           					      mcmc(t(a$theta.samples)))), 
-          			      autoburnin = FALSE)$psrf[, 2]
+          			      autoburnin = FALSE, multivariate = FALSE)$psrf[, 2]
         if (p.re > 0) {
           out$rhat$sigma.sq.psi <- as.vector(gelman.diag(mcmc.list(lapply(out.tmp, function(a) 
           					       mcmc(t(a$sigma.sq.psi.samples)))), 
-          			           autoburnin = FALSE)$psrf[, 2])
+          			           autoburnin = FALSE, multivariate = FALSE)$psrf[, 2])
         }
 
       } else {
