@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -112,7 +113,7 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
+      Rf_warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
       nThreads = 1;
     }
 #endif
@@ -217,33 +218,33 @@ extern "C" {
      * *******************************************************************/
     // Community level
     SEXP betaCommSamples_r; 
-    PROTECT(betaCommSamples_r = allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
+    PROTECT(betaCommSamples_r = Rf_allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
     SEXP alphaCommSamples_r;
-    PROTECT(alphaCommSamples_r = allocMatrix(REALSXP, pDet, nPost)); nProtect++;
+    PROTECT(alphaCommSamples_r = Rf_allocMatrix(REALSXP, pDet, nPost)); nProtect++;
     SEXP tauSqBetaSamples_r; 
-    PROTECT(tauSqBetaSamples_r = allocMatrix(REALSXP, pOcc, nPost)); nProtect++; 
+    PROTECT(tauSqBetaSamples_r = Rf_allocMatrix(REALSXP, pOcc, nPost)); nProtect++; 
     SEXP tauSqAlphaSamples_r; 
-    PROTECT(tauSqAlphaSamples_r = allocMatrix(REALSXP, pDet, nPost)); nProtect++; 
+    PROTECT(tauSqAlphaSamples_r = Rf_allocMatrix(REALSXP, pDet, nPost)); nProtect++; 
     // Species level
     SEXP betaSamples_r;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, pOccN, nPost)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, pOccN, nPost)); nProtect++;
     SEXP alphaSamples_r; 
-    PROTECT(alphaSamples_r = allocMatrix(REALSXP, nAlpha, nPost)); nProtect++;
+    PROTECT(alphaSamples_r = Rf_allocMatrix(REALSXP, nAlpha, nPost)); nProtect++;
     SEXP zSamples_r; 
-    PROTECT(zSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+    PROTECT(zSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++; 
     SEXP psiSamples_r; 
-    PROTECT(psiSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+    PROTECT(psiSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++; 
     // Occurrence random effects
     SEXP sigmaSqPsiSamples_r; 
     SEXP betaStarSamples_r; 
     if (pOccRE > 0) {
-      PROTECT(sigmaSqPsiSamples_r = allocMatrix(REALSXP, pOccRE, nPost)); nProtect++;
-      PROTECT(betaStarSamples_r = allocMatrix(REALSXP, nOccREN, nPost)); nProtect++;
+      PROTECT(sigmaSqPsiSamples_r = Rf_allocMatrix(REALSXP, pOccRE, nPost)); nProtect++;
+      PROTECT(betaStarSamples_r = Rf_allocMatrix(REALSXP, nOccREN, nPost)); nProtect++;
     }
     // TODO: eventually make this separate across different data sets.
     // Likelihood samples for WAIC. 
     SEXP likeSamples_r;
-    PROTECT(likeSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++;
+    PROTECT(likeSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++;
     
     /**********************************************************************
      * Additional Sampler Prep
@@ -262,9 +263,9 @@ extern "C" {
 
     // For normal priors
     F77_NAME(dpotrf)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
     F77_NAME(dpotri)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri SigmaBetaCommInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri SigmaBetaCommInv failed\n");}
     double *SigmaBetaCommInvMuBeta = (double *) R_alloc(pOcc, sizeof(double)); 
     F77_NAME(dsymv)(lower, &pOcc, &one, SigmaBetaCommInv, &pOcc, muBetaComm, &inc, &zero, 
         	    SigmaBetaCommInvMuBeta, &inc FCONE);
@@ -292,9 +293,9 @@ extern "C" {
       } // i
       F77_NAME(dpotrf)(lower, &pDetLong[q], &SigmaAlphaCommInv[alphaCommSigmaIndx[q]], 
 		       &pDetLong[q], &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf SigmaAlphaCommInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf SigmaAlphaCommInv failed\n");}
       F77_NAME(dpotri)(lower, &pDetLong[q], &SigmaAlphaCommInv[alphaCommSigmaIndx[q]], &pDetLong[q], &info FCONE); 
-      if(info != 0){error("c++ error: dpotri SigmaAlphaCommInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri SigmaAlphaCommInv failed\n");}
       F77_NAME(dsymv)(lower, &pDetLong[q], &one, &SigmaAlphaCommInv[alphaCommSigmaIndx[q]], &pDetLong[q], &muAlphaComm[alphaCommMuIndx[q]], &inc, &zero, 
                      &SigmaAlphaCommInvMuAlpha[alphaCommMuIndx[q]], &inc FCONE);
     } // q
@@ -366,12 +367,12 @@ extern "C" {
         tmp_ppOcc[q] = SigmaBetaCommInv[q] + N * TauBetaInv[q]; 
       }
       F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf ABetaComm failed\n");}
       F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotri ABetaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri ABetaComm failed\n");}
       F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
       F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf ABetaComm failed\n");}
       mvrnorm(betaComm, tmp_pOcc2, tmp_ppOcc, pOcc);
 
       /********************************************************************
@@ -401,12 +402,12 @@ extern "C" {
                                   NLong[alphaCommIndx[q]] * TauAlphaInv[q * pDet + q]; 
       }
       F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf AAlphaComm1 failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf AAlphaComm1 failed\n");}
       F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-      if(info != 0){error("c++ error: dpotri AAlphaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri AAlphaComm failed\n");}
       F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc FCONE);
       F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf AAlphaComm2 failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf AAlphaComm2 failed\n");}
       mvrnorm(alphaComm, tmp_pDet2, tmp_ppDet, pDet);
 
       /********************************************************************
@@ -424,9 +425,9 @@ extern "C" {
         TauBetaInv[q * pOcc + q] = tauSqBeta[q]; 
       } // q
       F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf TauBetaInv failed\n");}
       F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri TauBetaInv failed\n");}
 
       /********************************************************************
        Update Community Detection Variance Parameter
@@ -445,9 +446,9 @@ extern "C" {
         TauAlphaInv[q * pDet + q] = tauSqAlpha[q]; 
       } // q
       F77_NAME(dpotrf)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf TauAlphaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf TauAlphaInv failed\n");}
       F77_NAME(dpotri)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
-      if(info != 0){error("c++ error: dpotri TauAlphaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri TauAlphaInv failed\n");}
 
       /********************************************************************
        *Update Occupancy random effects variance
@@ -506,12 +507,12 @@ extern "C" {
           tmp_ppOcc[q] += TauBetaInv[q]; 
         } // q
         F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf ABeta failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf ABeta failed\n");}
         F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri ABeta failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotri ABeta failed\n");}
         F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
         F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf here failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf here failed\n");}
         mvrnorm(tmp_beta, tmp_pOcc2, tmp_ppOcc, pOcc);
         for (q = 0; q < pOcc; q++) {
           beta[q * N + i] = tmp_beta[q]; 
@@ -612,12 +613,12 @@ extern "C" {
               tmp_ppDet[r * pDetLong[q] + r] += 1.0 / tauSqAlpha[stAlphaComm + r]; 
             } // r
             F77_NAME(dpotrf)(lower, &pDetLong[q], tmp_ppDet, &pDetLong[q], &info FCONE); 
-            if(info != 0){error("c++ error: dpotrf A.alpha failed\n");}
+            if(info != 0){Rf_error("c++ error: dpotrf A.alpha failed\n");}
             F77_NAME(dpotri)(lower, &pDetLong[q], tmp_ppDet, &pDetLong[q], &info FCONE); 
-            if(info != 0){error("c++ error: dpotri A.alpha failed\n");}
+            if(info != 0){Rf_error("c++ error: dpotri A.alpha failed\n");}
             F77_NAME(dsymv)(lower, &pDetLong[q], &one, tmp_ppDet, &pDetLong[q], tmp_pDet, &inc, &zero, tmp_pDet2, &inc FCONE);
             F77_NAME(dpotrf)(lower, &pDetLong[q], tmp_ppDet, &pDetLong[q], &info FCONE); 
-            if(info != 0){error("c++ error: dpotrf here failed\n");}
+            if(info != 0){Rf_error("c++ error: dpotrf here failed\n");}
             mvrnorm(tmp_alpha, tmp_pDet2, tmp_ppDet, pDetLong[q]);
 	    currSize = 0; 
 	    for (r = 0; r < nAlpha; r++) {
@@ -735,8 +736,8 @@ extern "C" {
       nResultListObjs += 2;
     }
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     SET_VECTOR_ELT(result_r, 0, betaCommSamples_r);
     SET_VECTOR_ELT(result_r, 1, alphaCommSamples_r);
@@ -761,25 +762,25 @@ extern "C" {
       SET_VECTOR_ELT(result_r, tmp_0, sigmaSqPsiSamples_r);
       SET_VECTOR_ELT(result_r, tmp_0 + 1, betaStarSamples_r);
     }
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.comm.samples")); 
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("alpha.comm.samples")); 
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("tau.sq.beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 3, mkChar("tau.sq.alpha.samples")); 
-    SET_VECTOR_ELT(resultName_r, 4, mkChar("beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 5, mkChar("alpha.samples")); 
-    SET_VECTOR_ELT(resultName_r, 6, mkChar("z.samples")); 
-    SET_VECTOR_ELT(resultName_r, 7, mkChar("psi.samples")); 
-    SET_VECTOR_ELT(resultName_r, 8, mkChar("like.samples")); 
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.comm.samples")); 
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("alpha.comm.samples")); 
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("tau.sq.beta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("tau.sq.alpha.samples")); 
+    SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("beta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("alpha.samples")); 
+    SET_VECTOR_ELT(resultName_r, 6, Rf_mkChar("z.samples")); 
+    SET_VECTOR_ELT(resultName_r, 7, Rf_mkChar("psi.samples")); 
+    SET_VECTOR_ELT(resultName_r, 8, Rf_mkChar("like.samples")); 
     // if (pDetRE > 0) {
-    //   SET_VECTOR_ELT(resultName_r, 9, mkChar("sigma.sq.p.samples")); 
-    //   SET_VECTOR_ELT(resultName_r, 10, mkChar("alpha.star.samples")); 
+    //   SET_VECTOR_ELT(resultName_r, 9, Rf_mkChar("sigma.sq.p.samples")); 
+    //   SET_VECTOR_ELT(resultName_r, 10, Rf_mkChar("alpha.star.samples")); 
     // }
     if (pOccRE > 0) {
-      SET_VECTOR_ELT(resultName_r, tmp_0, mkChar("sigma.sq.psi.samples")); 
-      SET_VECTOR_ELT(resultName_r, tmp_0 + 1, mkChar("beta.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_0, Rf_mkChar("sigma.sq.psi.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_0 + 1, Rf_mkChar("beta.star.samples")); 
     }
    
-    namesgets(result_r, resultName_r);
+    Rf_namesgets(result_r, resultName_r);
     
     UNPROTECT(nProtect);
     
