@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -83,7 +84,7 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
+      Rf_warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
       nThreads = 1;
     }
 #endif
@@ -189,42 +190,42 @@ extern "C" {
      * *******************************************************************/
     // Community level
     SEXP betaCommSamples_r; 
-    PROTECT(betaCommSamples_r = allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
+    PROTECT(betaCommSamples_r = Rf_allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
     zeros(REAL(betaCommSamples_r), pOcc * nPost);
     SEXP tauSqBetaSamples_r; 
-    PROTECT(tauSqBetaSamples_r = allocMatrix(REALSXP, pOcc, nPost)); nProtect++; 
+    PROTECT(tauSqBetaSamples_r = Rf_allocMatrix(REALSXP, pOcc, nPost)); nProtect++; 
     zeros(REAL(tauSqBetaSamples_r), pOcc * nPost);
     // Species level
     SEXP betaSamples_r;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, pOccN, nPost)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, pOccN, nPost)); nProtect++;
     zeros(REAL(betaSamples_r), pOccN * nPost);
     SEXP psiSamples_r; 
-    PROTECT(psiSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
-    PROTECT(psiSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+    PROTECT(psiSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+    PROTECT(psiSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++; 
     // Factor model parameters
     SEXP lambdaSamples_r; 
-    PROTECT(lambdaSamples_r = allocMatrix(REALSXP, Nq, nPost)); nProtect++;
+    PROTECT(lambdaSamples_r = Rf_allocMatrix(REALSXP, Nq, nPost)); nProtect++;
     zeros(REAL(lambdaSamples_r), Nq * nPost);
     SEXP wSamples_r; 
-    PROTECT(wSamples_r = allocMatrix(REALSXP, Jq, nPost)); nProtect++; 
+    PROTECT(wSamples_r = Rf_allocMatrix(REALSXP, Jq, nPost)); nProtect++; 
     zeros(REAL(wSamples_r), Jq * nPost);
     // Fitted values
     double *z = (double *) R_alloc(JN, sizeof(double)); zeros(z, JN);
     SEXP zSamples_r; 
-    PROTECT(zSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+    PROTECT(zSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++; 
     zeros(REAL(zSamples_r), JN * nPost);
     // Occurrence random effects
     SEXP sigmaSqPsiSamples_r; 
     SEXP betaStarSamples_r; 
     if (pOccRE > 0) {
-      PROTECT(sigmaSqPsiSamples_r = allocMatrix(REALSXP, pOccRE, nPost)); nProtect++;
+      PROTECT(sigmaSqPsiSamples_r = Rf_allocMatrix(REALSXP, pOccRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqPsiSamples_r), pOccRE * nPost);
-      PROTECT(betaStarSamples_r = allocMatrix(REALSXP, nOccREN, nPost)); nProtect++;
+      PROTECT(betaStarSamples_r = Rf_allocMatrix(REALSXP, nOccREN, nPost)); nProtect++;
       zeros(REAL(betaStarSamples_r), nOccREN * nPost);
     }
     // Likelihood samples for WAIC. 
     SEXP likeSamples_r;
-    PROTECT(likeSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++;
+    PROTECT(likeSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++;
     zeros(REAL(likeSamples_r), JN * nPost);
     
     /**********************************************************************
@@ -239,9 +240,9 @@ extern "C" {
     // For normal community-level priors
     // Occurrence coefficients
     F77_NAME(dpotrf)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
     F77_NAME(dpotri)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri SigmaBetaCommInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri SigmaBetaCommInv failed\n");}
     double *SigmaBetaCommInvMuBeta = (double *) R_alloc(pOcc, sizeof(double)); 
     // dgemv computes linear combinations of different variables. 
     F77_NAME(dsymv)(lower, &pOcc, &one, SigmaBetaCommInv, &pOcc, muBetaComm, &inc, &zero, 
@@ -252,9 +253,9 @@ extern "C" {
       TauBetaInv[i * pOcc + i] = tauSqBeta[i]; 
     } // i
     F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf TauBetaInv failed\n");}
     F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri TauBetaInv failed\n");}
 
     /**********************************************************************
      * Prep for random effects (if they exist)
@@ -319,15 +320,15 @@ extern "C" {
         tmp_ppOcc[h] = SigmaBetaCommInv[h] + N * TauBetaInv[h]; 
       }
       F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf ABetaComm failed\n");}
       F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotri ABetaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri ABetaComm failed\n");}
       // A.beta.inv %*% b.beta
       // 1 * tmp_ppOcc * tmp_pOcc + 0 * tmp_pOcc2  = tmp_pOcc2
       F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
       // Computes cholesky of tmp_pp again stored back in tmp_ppOcc. This chol(A.beta.inv)
       F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf ABetaComm failed\n");}
       // Args: destination, mu, cholesky of the inverse covariance matrix, dimension
       mvrnorm(betaComm, tmp_pOcc2, tmp_ppOcc, pOcc);
 
@@ -347,9 +348,9 @@ extern "C" {
         TauBetaInv[h * pOcc + h] = tauSqBeta[h]; 
       } // i
       F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf TauBetaInv failed\n");}
       F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri TauBetaInv failed\n");}
 
       /********************************************************************
        *Update Occupancy random effects variance
@@ -408,13 +409,13 @@ extern "C" {
           tmp_ppOcc[h] += TauBetaInv[h]; 
         } // j
         F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf ABeta failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf ABeta failed\n");}
         F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri ABeta failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotri ABeta failed\n");}
         // A.beta.inv %*% b.beta
         F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
         F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-	if(info != 0){error("c++ error: dpotrf A.beta 2 failed\n");}
+	if(info != 0){Rf_error("c++ error: dpotrf A.beta 2 failed\n");}
         // Args: destination, mu, cholesky of the covariance matrix, dimension
         mvrnorm(tmp_beta, tmp_pOcc2, tmp_ppOcc, pOcc);
         // Can eventually get rid of this and change order of beta. 
@@ -480,9 +481,9 @@ extern "C" {
             var[k * q + k] += 1.0; 
           } // k
           F77_NAME(dpotrf)(lower, &q, var, &q, &info FCONE);
-          if (info != 0){error("c++ error: dpotrf var failed\n");}
+          if (info != 0){Rf_error("c++ error: dpotrf var failed\n");}
           F77_NAME(dpotri)(lower, &q, var, &q, &info FCONE);
-          if (info != 0){error("c++ error: dpotri var failed\n");}
+          if (info != 0){Rf_error("c++ error: dpotri var failed\n");}
 
           // mu
           for (k = 0; k < N; k++) {
@@ -494,7 +495,7 @@ extern "C" {
           F77_NAME(dsymv)(lower, &q, &one, var, &q, mu, &inc, &zero, tmp_N, &inc FCONE);
 
           F77_NAME(dpotrf)(lower, &q, var, &q, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf var 2 failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf var 2 failed\n");}
 
           mvrnorm(&w[ii * q], tmp_N, var, q);
 
@@ -568,14 +569,14 @@ extern "C" {
           } // j
 
           F77_NAME(dpotrf)(lower, &currDim, tmp_qq2, &currDim, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf for spatial factors failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf for spatial factors failed\n");}
           F77_NAME(dpotri)(lower, &currDim, tmp_qq2, &currDim, &info FCONE); 
-          if(info != 0){error("c++ error: dpotri for spatial factors failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotri for spatial factors failed\n");}
 
           F77_NAME(dsymv)(lower, &currDim, &one, tmp_qq2, &currDim, tmp_q, &inc, &zero, tmp_q2, &inc FCONE);
 
           F77_NAME(dpotrf)(lower, &currDim, tmp_qq2, &currDim, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf for spatial factors 2 failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf for spatial factors 2 failed\n");}
           
           mvrnorm(tmp_q, tmp_q2, tmp_qq2, currDim);
           F77_NAME(dcopy)(&currDim, tmp_q, &inc, &lambda[i], &N);
@@ -657,8 +658,8 @@ extern "C" {
       nResultListObjs += 2;
     }
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     // Setting the components of the output list.
     SET_VECTOR_ELT(result_r, 0, betaCommSamples_r);
@@ -675,22 +676,22 @@ extern "C" {
     }
 
 
-    // mkChar turns a C string into a CHARSXP
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.comm.samples")); 
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("tau.sq.beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 3, mkChar("z.samples")); 
-    SET_VECTOR_ELT(resultName_r, 4, mkChar("psi.samples")); 
-    SET_VECTOR_ELT(resultName_r, 5, mkChar("lambda.samples")); 
-    SET_VECTOR_ELT(resultName_r, 6, mkChar("w.samples")); 
-    SET_VECTOR_ELT(resultName_r, 7, mkChar("like.samples")); 
+    // Rf_mkChar turns a C string into a CHARSXP
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.comm.samples")); 
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("tau.sq.beta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("beta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("z.samples")); 
+    SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("psi.samples")); 
+    SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("lambda.samples")); 
+    SET_VECTOR_ELT(resultName_r, 6, Rf_mkChar("w.samples")); 
+    SET_VECTOR_ELT(resultName_r, 7, Rf_mkChar("like.samples")); 
     if (pOccRE > 0) {
-      SET_VECTOR_ELT(resultName_r, 8, mkChar("sigma.sq.psi.samples")); 
-      SET_VECTOR_ELT(resultName_r, 9, mkChar("beta.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, 8, Rf_mkChar("sigma.sq.psi.samples")); 
+      SET_VECTOR_ELT(resultName_r, 9, Rf_mkChar("beta.star.samples")); 
     }
    
     // Set the names of the output list.  
-    namesgets(result_r, resultName_r);
+    Rf_namesgets(result_r, resultName_r);
     
     //unprotect
     UNPROTECT(nProtect);
