@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -105,7 +106,7 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
+      Rf_warning("n.omp.threads > 1, but source not compiled with OpenMP support.");
       nThreads = 1;
     }
 #endif
@@ -212,51 +213,51 @@ extern "C" {
      * *******************************************************************/
     // Community level
     SEXP betaCommSamples_r; 
-    PROTECT(betaCommSamples_r = allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
+    PROTECT(betaCommSamples_r = Rf_allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
     zeros(REAL(betaCommSamples_r), pOcc * nPost);
     SEXP alphaCommSamples_r;
-    PROTECT(alphaCommSamples_r = allocMatrix(REALSXP, pDet, nPost)); nProtect++;
+    PROTECT(alphaCommSamples_r = Rf_allocMatrix(REALSXP, pDet, nPost)); nProtect++;
     zeros(REAL(alphaCommSamples_r), pDet * nPost);
     SEXP tauSqBetaSamples_r; 
-    PROTECT(tauSqBetaSamples_r = allocMatrix(REALSXP, pOcc, nPost)); nProtect++; 
+    PROTECT(tauSqBetaSamples_r = Rf_allocMatrix(REALSXP, pOcc, nPost)); nProtect++; 
     zeros(REAL(tauSqBetaSamples_r), pOcc * nPost);
     SEXP tauSqAlphaSamples_r; 
-    PROTECT(tauSqAlphaSamples_r = allocMatrix(REALSXP, pDet, nPost)); nProtect++; 
+    PROTECT(tauSqAlphaSamples_r = Rf_allocMatrix(REALSXP, pDet, nPost)); nProtect++; 
     zeros(REAL(tauSqAlphaSamples_r), pDet * nPost);
     // Species level
     SEXP betaSamples_r;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, pOccN, nPost)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, pOccN, nPost)); nProtect++;
     zeros(REAL(betaSamples_r), pOccN * nPost);
     SEXP alphaSamples_r; 
-    PROTECT(alphaSamples_r = allocMatrix(REALSXP, pDetN, nPost)); nProtect++;
+    PROTECT(alphaSamples_r = Rf_allocMatrix(REALSXP, pDetN, nPost)); nProtect++;
     zeros(REAL(alphaSamples_r), pDetN * nPost);
     SEXP zSamples_r; 
-    PROTECT(zSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+    PROTECT(zSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++; 
     zeros(REAL(zSamples_r), JN * nPost);
     SEXP psiSamples_r; 
-    PROTECT(psiSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+    PROTECT(psiSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++; 
     zeros(REAL(psiSamples_r), JN * nPost);
     // Detection random effects
     SEXP sigmaSqPSamples_r; 
     SEXP alphaStarSamples_r; 
     if (pDetRE > 0) {
-      PROTECT(sigmaSqPSamples_r = allocMatrix(REALSXP, pDetRE, nPost)); nProtect++;
+      PROTECT(sigmaSqPSamples_r = Rf_allocMatrix(REALSXP, pDetRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqPSamples_r), pDetRE * nPost);
-      PROTECT(alphaStarSamples_r = allocMatrix(REALSXP, nDetREN, nPost)); nProtect++;
+      PROTECT(alphaStarSamples_r = Rf_allocMatrix(REALSXP, nDetREN, nPost)); nProtect++;
       zeros(REAL(alphaStarSamples_r), nDetREN * nPost);
     }
     // Occurrence random effects
     SEXP sigmaSqPsiSamples_r; 
     SEXP betaStarSamples_r; 
     if (pOccRE > 0) {
-      PROTECT(sigmaSqPsiSamples_r = allocMatrix(REALSXP, pOccRE, nPost)); nProtect++;
+      PROTECT(sigmaSqPsiSamples_r = Rf_allocMatrix(REALSXP, pOccRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqPsiSamples_r), pOccRE * nPost);
-      PROTECT(betaStarSamples_r = allocMatrix(REALSXP, nOccREN, nPost)); nProtect++;
+      PROTECT(betaStarSamples_r = Rf_allocMatrix(REALSXP, nOccREN, nPost)); nProtect++;
       zeros(REAL(betaStarSamples_r), nOccREN * nPost);
     }
     // Likelihood samples for WAIC. 
     SEXP likeSamples_r;
-    PROTECT(likeSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++;
+    PROTECT(likeSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++;
     zeros(REAL(likeSamples_r), JN * nPost);
     
     /**********************************************************************
@@ -276,17 +277,17 @@ extern "C" {
 
     // For normal priors
     F77_NAME(dpotrf)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
     F77_NAME(dpotri)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri SigmaBetaCommInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri SigmaBetaCommInv failed\n");}
     double *SigmaBetaCommInvMuBeta = (double *) R_alloc(pOcc, sizeof(double)); 
     F77_NAME(dsymv)(lower, &pOcc, &one, SigmaBetaCommInv, &pOcc, muBetaComm, &inc, &zero, 
         	    SigmaBetaCommInvMuBeta, &inc FCONE);
     // Detection regression coefficient priors. 
     F77_NAME(dpotrf)(lower, &pDet, SigmaAlphaCommInv, &pDet, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf SigmaAlphaCommInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf SigmaAlphaCommInv failed\n");}
     F77_NAME(dpotri)(lower, &pDet, SigmaAlphaCommInv, &pDet, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri SigmaAlphaCommInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri SigmaAlphaCommInv failed\n");}
     double *SigmaAlphaCommInvMuAlpha = (double *) R_alloc(pDet, sizeof(double)); 
     F77_NAME(dsymv)(lower, &pDet, &one, SigmaAlphaCommInv, &pDet, muAlphaComm, &inc, &zero, 
                    SigmaAlphaCommInvMuAlpha, &inc FCONE);
@@ -364,12 +365,12 @@ extern "C" {
         tmp_ppOcc[q] = SigmaBetaCommInv[q] + N * TauBetaInv[q]; 
       }
       F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf ABetaComm failed\n");}
       F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotri ABetaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri ABetaComm failed\n");}
       F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
       F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf ABetaComm failed\n");}
       mvrnorm(betaComm, tmp_pOcc2, tmp_ppOcc, pOcc);
       /********************************************************************
        Update Community level Detection Coefficients
@@ -391,12 +392,12 @@ extern "C" {
         tmp_ppDet[q] = SigmaAlphaCommInv[q] + N * TauAlphaInv[q]; 
       }
       F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf AAlphaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf AAlphaComm failed\n");}
       F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-      if(info != 0){error("c++ error: dpotri AAlphaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri AAlphaComm failed\n");}
       F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc FCONE);
       F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf AAlphaComm failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf AAlphaComm failed\n");}
       mvrnorm(alphaComm, tmp_pDet2, tmp_ppDet, pDet);
 
       /********************************************************************
@@ -414,9 +415,9 @@ extern "C" {
         TauBetaInv[q * pOcc + q] = tauSqBeta[q]; 
       } // q
       F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf TauBetaInv failed\n");}
       F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-      if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri TauBetaInv failed\n");}
       /********************************************************************
        Update Community Detection Variance Parameter
       ********************************************************************/
@@ -432,9 +433,9 @@ extern "C" {
         TauAlphaInv[q * pDet + q] = tauSqAlpha[q]; 
       } // q
       F77_NAME(dpotrf)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf TauAlphaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf TauAlphaInv failed\n");}
       F77_NAME(dpotri)(lower, &pDet, TauAlphaInv, &pDet, &info FCONE); 
-      if(info != 0){error("c++ error: dpotri TauAlphaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri TauAlphaInv failed\n");}
 
       /********************************************************************
        *Update Occupancy random effects variance
@@ -513,12 +514,12 @@ extern "C" {
           tmp_ppOcc[q] += TauBetaInv[q]; 
         } // q
         F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf ABeta failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf ABeta failed\n");}
         F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri ABeta failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotri ABeta failed\n");}
         F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
         F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf here failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf here failed\n");}
         mvrnorm(tmp_beta, tmp_pOcc2, tmp_ppOcc, pOcc);
         for (q = 0; q < pOcc; q++) {
           beta[q * N + i] = tmp_beta[q]; 
@@ -563,12 +564,12 @@ extern "C" {
           tmp_ppDet[q] += TauAlphaInv[q]; 
         } // q
         F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf A.alpha failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf A.alpha failed\n");}
         F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri A.alpha failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotri A.alpha failed\n");}
         F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc FCONE);
         F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf here failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf here failed\n");}
         mvrnorm(tmp_alpha, tmp_pDet2, tmp_ppDet, pDet);
         for (q = 0; q < pDet; q++) {
           alpha[q * N + i] = tmp_alpha[q];
@@ -760,8 +761,8 @@ extern "C" {
       nResultListObjs += 2;
     }
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     SET_VECTOR_ELT(result_r, 0, betaCommSamples_r);
     SET_VECTOR_ELT(result_r, 1, alphaCommSamples_r);
@@ -785,25 +786,25 @@ extern "C" {
       SET_VECTOR_ELT(result_r, tmp_0, sigmaSqPsiSamples_r);
       SET_VECTOR_ELT(result_r, tmp_0 + 1, betaStarSamples_r);
     }
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.comm.samples")); 
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("alpha.comm.samples")); 
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("tau.sq.beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 3, mkChar("tau.sq.alpha.samples")); 
-    SET_VECTOR_ELT(resultName_r, 4, mkChar("beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 5, mkChar("alpha.samples")); 
-    SET_VECTOR_ELT(resultName_r, 6, mkChar("z.samples")); 
-    SET_VECTOR_ELT(resultName_r, 7, mkChar("psi.samples")); 
-    SET_VECTOR_ELT(resultName_r, 8, mkChar("like.samples")); 
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.comm.samples")); 
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("alpha.comm.samples")); 
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("tau.sq.beta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("tau.sq.alpha.samples")); 
+    SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("beta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("alpha.samples")); 
+    SET_VECTOR_ELT(resultName_r, 6, Rf_mkChar("z.samples")); 
+    SET_VECTOR_ELT(resultName_r, 7, Rf_mkChar("psi.samples")); 
+    SET_VECTOR_ELT(resultName_r, 8, Rf_mkChar("like.samples")); 
     if (pDetRE > 0) {
-      SET_VECTOR_ELT(resultName_r, 9, mkChar("sigma.sq.p.samples")); 
-      SET_VECTOR_ELT(resultName_r, 10, mkChar("alpha.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, 9, Rf_mkChar("sigma.sq.p.samples")); 
+      SET_VECTOR_ELT(resultName_r, 10, Rf_mkChar("alpha.star.samples")); 
     }
     if (pOccRE > 0) {
-      SET_VECTOR_ELT(resultName_r, tmp_0, mkChar("sigma.sq.psi.samples")); 
-      SET_VECTOR_ELT(resultName_r, tmp_0 + 1, mkChar("beta.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_0, Rf_mkChar("sigma.sq.psi.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_0 + 1, Rf_mkChar("beta.star.samples")); 
     }
    
-    namesgets(result_r, resultName_r);
+    Rf_namesgets(result_r, resultName_r);
     
     UNPROTECT(nProtect);
     
