@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -48,8 +49,8 @@ void updateBF1JSDM(double *B, double *F, double *c, double *C, double *coords, i
 	    C[mm*threadID+l*nnIndxLU[n+i]+k] = sigmaSq*spCor(e, phi, nu, covModel, &bk[threadID*nb]); 
 	  }
 	}
-	F77_NAME(dpotrf)(&lower, &nnIndxLU[n+i], &C[mm*threadID], &nnIndxLU[n+i], &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
-	F77_NAME(dpotri)(&lower, &nnIndxLU[n+i], &C[mm*threadID], &nnIndxLU[n+i], &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+	F77_NAME(dpotrf)(&lower, &nnIndxLU[n+i], &C[mm*threadID], &nnIndxLU[n+i], &info FCONE); if(info != 0){Rf_error("c++ error: dpotrf failed\n");}
+	F77_NAME(dpotri)(&lower, &nnIndxLU[n+i], &C[mm*threadID], &nnIndxLU[n+i], &info FCONE); if(info != 0){Rf_error("c++ error: dpotri failed\n");}
 	F77_NAME(dsymv)(&lower, &nnIndxLU[n+i], &one, &C[mm*threadID], &nnIndxLU[n+i], &c[m*threadID], &inc, &zero, &B[nnIndxLU[i]], &inc FCONE);
 	F[i] = sigmaSq - F77_NAME(ddot)(&nnIndxLU[n+i], &B[nnIndxLU[i]], &inc, &c[m*threadID], &inc);
       }else{
@@ -165,7 +166,7 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
+      Rf_warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
       nThreads = 1;
     }
 #endif
@@ -285,41 +286,41 @@ extern "C" {
     // Community level
     SEXP betaCommSamples_r; 
     if (monitors[betaCommMonitor]) {
-      PROTECT(betaCommSamples_r = allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
+      PROTECT(betaCommSamples_r = Rf_allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
       zeros(REAL(betaCommSamples_r), pOcc * nPost);
     }
     SEXP tauSqBetaSamples_r;
     if (monitors[tauSqBetaMonitor]) {
-      PROTECT(tauSqBetaSamples_r = allocMatrix(REALSXP, pOcc, nPost)); nProtect++; 
+      PROTECT(tauSqBetaSamples_r = Rf_allocMatrix(REALSXP, pOcc, nPost)); nProtect++; 
       zeros(REAL(tauSqBetaSamples_r), pOcc * nPost);
     }
     // Species level
     SEXP betaSamples_r;
     if (monitors[betaMonitor]) {
-      PROTECT(betaSamples_r = allocMatrix(REALSXP, pOccN, nPost)); nProtect++;
+      PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, pOccN, nPost)); nProtect++;
       zeros(REAL(betaSamples_r), pOccN * nPost);
     }
     // Fitted values
     double *z = (double *) R_alloc(JN, sizeof(double)); zeros(z, JN);
     SEXP zSamples_r; 
     if (monitors[zMonitor]) {
-      PROTECT(zSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+      PROTECT(zSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++; 
       zeros(REAL(zSamples_r), JN * nPost);
     }
     SEXP psiSamples_r; 
     if (monitors[psiMonitor]) {
-      PROTECT(psiSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++; 
+      PROTECT(psiSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++; 
       zeros(REAL(psiSamples_r), JN * nPost);
     }
     // Spatial parameters
     SEXP lambdaSamples_r; 
     if (monitors[lambdaMonitor]) {
-      PROTECT(lambdaSamples_r = allocMatrix(REALSXP, Nq, nPost)); nProtect++;
+      PROTECT(lambdaSamples_r = Rf_allocMatrix(REALSXP, Nq, nPost)); nProtect++;
       zeros(REAL(lambdaSamples_r), Nq * nPost);
     }
     SEXP wSamples_r; 
     if (monitors[wMonitor]) {
-      PROTECT(wSamples_r = allocMatrix(REALSXP, Jq, nPost)); nProtect++; 
+      PROTECT(wSamples_r = Rf_allocMatrix(REALSXP, Jq, nPost)); nProtect++; 
       zeros(REAL(wSamples_r), Jq * nPost);
     }
     // Occurrence random effects
@@ -327,18 +328,18 @@ extern "C" {
     SEXP betaStarSamples_r; 
     if (pOccRE > 0) {
       if (monitors[sigmaSqPsiMonitor]) {
-        PROTECT(sigmaSqPsiSamples_r = allocMatrix(REALSXP, pOccRE, nPost)); nProtect++;
+        PROTECT(sigmaSqPsiSamples_r = Rf_allocMatrix(REALSXP, pOccRE, nPost)); nProtect++;
         zeros(REAL(sigmaSqPsiSamples_r), pOccRE * nPost);
       }
       if (monitors[betaStarMonitor]) {
-        PROTECT(betaStarSamples_r = allocMatrix(REALSXP, nOccREN, nPost)); nProtect++;
+        PROTECT(betaStarSamples_r = Rf_allocMatrix(REALSXP, nOccREN, nPost)); nProtect++;
         zeros(REAL(betaStarSamples_r), nOccREN * nPost);
       }
     }
     // Likelihood samples for WAIC. 
     SEXP likeSamples_r;
     if (monitors[likeMonitor]) {
-      PROTECT(likeSamples_r = allocMatrix(REALSXP, JN, nPost)); nProtect++;
+      PROTECT(likeSamples_r = Rf_allocMatrix(REALSXP, JN, nPost)); nProtect++;
       zeros(REAL(likeSamples_r), JN * nPost);
     }
     
@@ -353,9 +354,9 @@ extern "C" {
     // For normal community-level priors
     // Occurrence coefficients
     F77_NAME(dpotrf)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf SigmaBetaCommInv failed\n");}
     F77_NAME(dpotri)(lower, &pOcc, SigmaBetaCommInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri SigmaBetaCommInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri SigmaBetaCommInv failed\n");}
     double *SigmaBetaCommInvMuBeta = (double *) R_alloc(pOcc, sizeof(double)); 
     F77_NAME(dsymv)(lower, &pOcc, &one, SigmaBetaCommInv, &pOcc, muBetaComm, &inc, &zero, 
         	    SigmaBetaCommInvMuBeta, &inc FCONE);
@@ -365,9 +366,9 @@ extern "C" {
       TauBetaInv[i * pOcc + i] = tauSqBeta[i]; 
     } // i
     F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf TauBetaInv failed\n");}
     F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri TauBetaInv failed\n");}
 
     /**********************************************************************
      * Prep for random effects (if they exist)
@@ -427,7 +428,7 @@ extern "C" {
     } // ll
     SEXP thetaSamples_r; 
     if (monitors[thetaMonitor]) {
-      PROTECT(thetaSamples_r = allocMatrix(REALSXP, nThetaqSave, nPost)); nProtect++; 
+      PROTECT(thetaSamples_r = Rf_allocMatrix(REALSXP, nThetaqSave, nPost)); nProtect++; 
       zeros(REAL(thetaSamples_r), nThetaqSave * nPost);
     }
     // Species-level spatial random effects
@@ -478,7 +479,7 @@ extern "C" {
     // MCMC info if desired
     double *accept2 = (double *) R_alloc(nThetaq, sizeof(double)); zeros(accept2, nThetaq);
     SEXP tuningSamples_r; 
-    PROTECT(tuningSamples_r = allocMatrix(REALSXP, nThetaq, inc)); nProtect++; 
+    PROTECT(tuningSamples_r = Rf_allocMatrix(REALSXP, nThetaq, inc)); nProtect++; 
     zeros(REAL(tuningSamples_r), nThetaq);
 
     GetRNGstate();
@@ -512,15 +513,15 @@ extern "C" {
             tmp_ppOcc[h] = SigmaBetaCommInv[h] + N * TauBetaInv[h]; 
           }
           F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf ABetaComm failed\n");}
           F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-          if(info != 0){error("c++ error: dpotri ABetaComm failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotri ABetaComm failed\n");}
           // A.beta.inv %*% b.beta
           // 1 * tmp_ppOcc * tmp_pOcc + 0 * tmp_pOcc2  = tmp_pOcc2
           F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
           // Computes cholesky of tmp_pp again stored back in tmp_ppOcc. This chol(A.beta.inv)
           F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf ABetaComm failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf ABetaComm failed\n");}
           // Args: destination, mu, cholesky of the inverse covariance matrix, dimension
           mvrnorm(betaComm, tmp_pOcc2, tmp_ppOcc, pOcc);
 	}
@@ -541,9 +542,9 @@ extern "C" {
             TauBetaInv[h * pOcc + h] = tauSqBeta[h]; 
           } // i
           F77_NAME(dpotrf)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf TauBetaInv failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf TauBetaInv failed\n");}
           F77_NAME(dpotri)(lower, &pOcc, TauBetaInv, &pOcc, &info FCONE); 
-          if(info != 0){error("c++ error: dpotri TauBetaInv failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotri TauBetaInv failed\n");}
 	}
         /********************************************************************
          *Update Occupancy random effects variance
@@ -608,13 +609,13 @@ extern "C" {
             tmp_ppOcc[h] += TauBetaInv[h]; 
           } // j
           F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf ABeta failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf ABeta failed\n");}
           F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-          if(info != 0){error("c++ error: dpotri ABeta failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotri ABeta failed\n");}
           // A.beta.inv %*% b.beta
           F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
           F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-	  if(info != 0){error("c++ error: dpotrf A.beta 2 failed\n");}
+	  if(info != 0){Rf_error("c++ error: dpotrf A.beta 2 failed\n");}
           // Args: destination, mu, cholesky of the covariance matrix, dimension
           mvrnorm(tmp_beta, tmp_pOcc2, tmp_ppOcc, pOcc);
           // Can eventually get rid of this and change order of beta. 
@@ -720,9 +721,9 @@ extern "C" {
             var[k * q + k] += ff[k] + v[k]; 
           } // k
           F77_NAME(dpotrf)(lower, &q, var, &q, &info FCONE);
-          if(info != 0){error("c++ error: dpotrf var failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf var failed\n");}
           F77_NAME(dpotri)(lower, &q, var, &q, &info FCONE);
-          if(info != 0){error("c++ error: dpotri var failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotri var failed\n");}
 
           // mu
           zeros(tmp_N, N);
@@ -741,7 +742,7 @@ extern "C" {
 	        F77_NAME(dsymv)(lower, &q, &one, var, &q, mu, &inc, &zero, tmp_N, &inc FCONE);
 
           F77_NAME(dpotrf)(lower, &q, var, &q, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf var 2 failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf var 2 failed\n");}
 
           mvrnorm(&w[ii * q], tmp_N, var, q);
         } // ii
@@ -820,14 +821,14 @@ extern "C" {
             } // j
 
             F77_NAME(dpotrf)(lower, &currDim, tmp_qq2, &currDim, &info FCONE); 
-	    if(info != 0){error("c++ error: dpotrf for spatial factors failed\n");}
+	    if(info != 0){Rf_error("c++ error: dpotrf for spatial factors failed\n");}
             F77_NAME(dpotri)(lower, &currDim, tmp_qq2, &currDim, &info FCONE); 
-	    if(info != 0){error("c++ error: dpotri for spatial factors failed\n");}
+	    if(info != 0){Rf_error("c++ error: dpotri for spatial factors failed\n");}
 
             F77_NAME(dsymv)(lower, &currDim, &one, tmp_qq2, &currDim, tmp_q, &inc, &zero, tmp_q2, &inc FCONE);
 
             F77_NAME(dpotrf)(lower, &currDim, tmp_qq2, &currDim, &info FCONE); 
-	    if(info != 0){error("c++ error: dpotrf for spatial factors 2 failed\n");}
+	    if(info != 0){Rf_error("c++ error: dpotrf for spatial factors 2 failed\n");}
             
             mvrnorm(tmp_q, tmp_q2, tmp_qq2, currDim);
             F77_NAME(dcopy)(&currDim, tmp_q, &inc, &lambda[i], &N);
@@ -1074,8 +1075,8 @@ extern "C" {
       nResultListObjs += 2;
     }
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     // Setting the components of the output list.
     if (monitors[betaCommMonitor]) {
@@ -1115,46 +1116,46 @@ extern "C" {
       }
     }
 
-    // mkChar turns a C string into a CHARSXP
+    // Rf_mkChar turns a C string into a CHARSXP
     if (monitors[betaCommMonitor]) {
-      SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.comm.samples")); 
+      SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.comm.samples")); 
     }
     if (monitors[tauSqBetaMonitor]) {
-      SET_VECTOR_ELT(resultName_r, 1, mkChar("tau.sq.beta.samples")); 
+      SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("tau.sq.beta.samples")); 
     }
     if (monitors[betaMonitor]) {
-      SET_VECTOR_ELT(resultName_r, 2, mkChar("beta.samples")); 
+      SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("beta.samples")); 
     }
     if (monitors[zMonitor]) {
-      SET_VECTOR_ELT(resultName_r, 3, mkChar("z.samples")); 
+      SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("z.samples")); 
     }
     if (monitors[psiMonitor]) {
-      SET_VECTOR_ELT(resultName_r, 4, mkChar("psi.samples")); 
+      SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("psi.samples")); 
     }
     if (monitors[lambdaMonitor]) {
-      SET_VECTOR_ELT(resultName_r, 5, mkChar("lambda.samples")); 
+      SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("lambda.samples")); 
     }
     if (monitors[wMonitor]) {
-      SET_VECTOR_ELT(resultName_r, 6, mkChar("w.samples")); 
+      SET_VECTOR_ELT(resultName_r, 6, Rf_mkChar("w.samples")); 
     }
     if (monitors[thetaMonitor]) {
-      SET_VECTOR_ELT(resultName_r, 7, mkChar("theta.samples")); 
+      SET_VECTOR_ELT(resultName_r, 7, Rf_mkChar("theta.samples")); 
     }
     if (monitors[likeMonitor]) {
-      SET_VECTOR_ELT(resultName_r, 8, mkChar("like.samples")); 
+      SET_VECTOR_ELT(resultName_r, 8, Rf_mkChar("like.samples")); 
     }
-    SET_VECTOR_ELT(resultName_r, 9, mkChar("tuning"));
+    SET_VECTOR_ELT(resultName_r, 9, Rf_mkChar("tuning"));
     if (pOccRE > 0) {
       if (monitors[sigmaSqPsiMonitor]) {
-        SET_VECTOR_ELT(resultName_r, 10, mkChar("sigma.sq.psi.samples")); 
+        SET_VECTOR_ELT(resultName_r, 10, Rf_mkChar("sigma.sq.psi.samples")); 
       }
       if (monitors[betaStarMonitor]) {
-        SET_VECTOR_ELT(resultName_r, 11, mkChar("beta.star.samples")); 
+        SET_VECTOR_ELT(resultName_r, 11, Rf_mkChar("beta.star.samples")); 
       }
     }
    
     // Set the names of the output list.  
-    namesgets(result_r, resultName_r);
+    Rf_namesgets(result_r, resultName_r);
     
     //unprotect
     UNPROTECT(nProtect);
