@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -108,7 +109,7 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
+      Rf_warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
       nThreads = 1;
     }
 #endif
@@ -172,19 +173,19 @@ extern "C" {
      * Return Stuff
      * *******************************************************************/
     SEXP betaSamples_r;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
     zeros(REAL(betaSamples_r), pOcc * nPost);
     SEXP alphaSamples_r; 
-    PROTECT(alphaSamples_r = allocMatrix(REALSXP, pDet, nPost)); nProtect++;
+    PROTECT(alphaSamples_r = Rf_allocMatrix(REALSXP, pDet, nPost)); nProtect++;
     zeros(REAL(alphaSamples_r), pDet * nPost);
     SEXP zSamples_r; 
-    PROTECT(zSamples_r = allocMatrix(REALSXP, J, nPost)); nProtect++; 
+    PROTECT(zSamples_r = Rf_allocMatrix(REALSXP, J, nPost)); nProtect++; 
     zeros(REAL(zSamples_r), J * nPost);
     SEXP psiSamples_r; 
-    PROTECT(psiSamples_r = allocMatrix(REALSXP, J, nPost)); nProtect++; 
+    PROTECT(psiSamples_r = Rf_allocMatrix(REALSXP, J, nPost)); nProtect++; 
     zeros(REAL(psiSamples_r), J * nPost);
     SEXP wSamples_r; 
-    PROTECT(wSamples_r = allocMatrix(REALSXP, J, nPost)); nProtect++; 
+    PROTECT(wSamples_r = Rf_allocMatrix(REALSXP, J, nPost)); nProtect++; 
     zeros(REAL(wSamples_r), J * nPost);
     
     /**********************************************************************
@@ -221,10 +222,10 @@ extern "C" {
     // Occupancy regression coefficient priors. 
     // Compute cholesky
     F77_NAME(dpotrf)(lower, &pOcc, SigmaBetaInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf SigmaBetaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf SigmaBetaInv failed\n");}
     // Compute inverse
     F77_NAME(dpotri)(lower, &pOcc, SigmaBetaInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri SigmaBetaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri SigmaBetaInv failed\n");}
     double *SigmaBetaInvMuBeta = (double *) R_alloc(pOcc, sizeof(double)); 
     F77_NAME(dsymv)(lower, &pOcc, &one, SigmaBetaInv, &pOcc, muBeta, &inc, &zero, 
         	    SigmaBetaInvMuBeta, &inc FCONE);
@@ -254,9 +255,9 @@ extern "C" {
 	// Rprintf("Index: %i\n", alphaSigmaIndx[q] + i * pDetLong[q] + i); 
       } // i
       F77_NAME(dpotrf)(lower, &pDetLong[q], &SigmaAlphaInv[alphaSigmaIndx[q]], &pDetLong[q], &info FCONE); 
-      if(info != 0){error("c++ error: dpotrf SigmaAlphaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotrf SigmaAlphaInv failed\n");}
       F77_NAME(dpotri)(lower, &pDetLong[q], &SigmaAlphaInv[alphaSigmaIndx[q]], &pDetLong[q], &info FCONE); 
-      if(info != 0){error("c++ error: dpotri SigmaAlphaInv failed\n");}
+      if(info != 0){Rf_error("c++ error: dpotri SigmaAlphaInv failed\n");}
       F77_NAME(dsymv)(lower, &pDetLong[q], &one, &SigmaAlphaInv[alphaSigmaIndx[q]], &pDetLong[q], &muAlpha[alphaMuIndx[q]], &inc, &zero, 
                      &SigmaAlphaInvMuAlpha[alphaMuIndx[q]], &inc FCONE);
     } // q
@@ -277,13 +278,13 @@ extern "C" {
     double logMHRatio, logPostCurr = 0.0, logPostCand = 0.0, detCand = 0.0, detCurr = 0.0;
     double phiCand = 0.0, nuCand = 0.0, sigmaSqCand = 0.0;
     SEXP acceptSamples_r; 
-    PROTECT(acceptSamples_r = allocMatrix(REALSXP, nTheta, nBatch)); nProtect++; 
+    PROTECT(acceptSamples_r = Rf_allocMatrix(REALSXP, nTheta, nBatch)); nProtect++; 
     zeros(REAL(acceptSamples_r), nTheta * nBatch);
     SEXP tuningSamples_r; 
-    PROTECT(tuningSamples_r = allocMatrix(REALSXP, nTheta, nBatch)); nProtect++; 
+    PROTECT(tuningSamples_r = Rf_allocMatrix(REALSXP, nTheta, nBatch)); nProtect++; 
     zeros(REAL(tuningSamples_r), nTheta * nBatch);
     SEXP thetaSamples_r; 
-    PROTECT(thetaSamples_r = allocMatrix(REALSXP, nTheta, nPost)); nProtect++; 
+    PROTECT(thetaSamples_r = Rf_allocMatrix(REALSXP, nTheta, nPost)); nProtect++; 
     zeros(REAL(thetaSamples_r), nTheta * nPost);
     // Initiate spatial values
     theta[sigmaSqIndx] = REAL(sigmaSqStarting_r)[0]; 
@@ -307,10 +308,10 @@ extern "C" {
     spCovLT(coordsD, J, theta, corName, C); 
     // Get cholesky of C
     F77_NAME(dpotrf)(lower, &J, C, &J, &info FCONE); 
-    if(info != 0){error("c++ error: Cholesky failed in initial covariance matrix\n");}
+    if(info != 0){Rf_error("c++ error: Cholesky failed in initial covariance matrix\n");}
     // Get inverse Cholesky of C. 
     F77_NAME(dpotri)(lower, &J, C, &J, &info FCONE); 
-    if(info != 0){error("c++ error: Cholesky inverse failed in initial covariance matrix\n");}
+    if(info != 0){Rf_error("c++ error: Cholesky inverse failed in initial covariance matrix\n");}
     // C now contains the inverse of the covariance matrix. 
     // For sigmaSq sampler
     double aSigmaSqPost = 0.5 * J + sigmaSqA; 
@@ -370,13 +371,13 @@ extern "C" {
           tmp_ppOcc[j] += SigmaBetaInv[j]; 
         } // j
         F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf here failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf here failed\n");}
         F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri here failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotri here failed\n");}
         // 1 * tmp_ppOcc * tmp_pOcc + 0 * tmp_pOcc2 
         F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
         F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-	if(info != 0){error("c++ error: dpotrf here failed\n");}
+	if(info != 0){Rf_error("c++ error: dpotrf here failed\n");}
         // Args: destination, mu, cholesky of the covariance matrix, dimension
         mvrnorm(beta, tmp_pOcc2, tmp_ppOcc, pOcc);
 
@@ -431,17 +432,17 @@ extern "C" {
           // This gives the Cholesky of A.alpha
           // Computes cholesky of tmp_ppDet. Output stored in tmp_ppOcc
           F77_NAME(dpotrf)(lower, &pDetLong[q], &tmp_ppDet[alphaSigmaIndx[q]], &pDetLong[q], &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf A.alpha failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf A.alpha failed\n");}
           // Computes the inverse tmp_ppOcc. Stored in tmp_ppOcc. This is A.beta.inv. 
           F77_NAME(dpotri)(lower, &pDetLong[q], &tmp_ppDet[alphaSigmaIndx[q]], &pDetLong[q], &info FCONE); 
-          if(info != 0){error("c++ error: dpotri A.alpha failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotri A.alpha failed\n");}
           // A.alpha.inv %*% b.alpha
           // 1 * tmp_ppDet * tmp_pDet + 0 * tmp_pDet2 
           // (which is currently nothing) = tmp_pDet2
           F77_NAME(dsymv)(lower, &pDetLong[q], &one, &tmp_ppDet[alphaSigmaIndx[q]], &pDetLong[q], &tmp_pDet[stAlpha], &inc, &zero, &tmp_pDet2[stAlpha], &inc FCONE);
           // Computes cholesky of tmp_ppDet again stored back in tmp_ppDet. This chol(A.alpha.inv)
           F77_NAME(dpotrf)(lower, &pDetLong[q], &tmp_ppDet[alphaSigmaIndx[q]], &pDetLong[q], &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf here failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf here failed\n");}
           // Args: destination, mu, cholesky of the covariance matrix, dimension
           mvrnorm(&alpha[stAlpha], &tmp_pDet2[stAlpha], &tmp_ppDet[alphaSigmaIndx[q]], pDetLong[q]);
           // for (j = 0; j < pDetLong[q]; j++) {
@@ -501,13 +502,13 @@ extern "C" {
 	// Invert CCand and log det cov. 
         detCand = 0.0;
 	F77_NAME(dpotrf)(lower, &J, CCand, &J, &info FCONE); 
-	if(info != 0){error("c++ error: Cholesky failed in covariance matrix\n");}
+	if(info != 0){Rf_error("c++ error: Cholesky failed in covariance matrix\n");}
 	// Get log of the determinant of the covariance matrix. 
 	for (k = 0; k < J; k++) {
 	  detCand += 2.0 * log(CCand[k*J+k]);
 	} // k
 	F77_NAME(dpotri)(lower, &J, CCand, &J, &info FCONE); 
-	if(info != 0){error("c++ error: Cholesky inverse failed in covariance matrix\n");}
+	if(info != 0){Rf_error("c++ error: Cholesky inverse failed in covariance matrix\n");}
         logPostCand = 0.0; 
 	// Jacobian and Uniform prior. 
 	logPostCand += log(phiCand - phiA) + log(phiB - phiCand); 
@@ -535,12 +536,12 @@ extern "C" {
 	spCovLT(coordsD, J, theta, corName, C); 
         detCurr = 0.0;
 	F77_NAME(dpotrf)(lower, &J, C, &J, &info FCONE); 
-	if(info != 0){error("c++ error: Cholesky failed in covariance matrix\n");}
+	if(info != 0){Rf_error("c++ error: Cholesky failed in covariance matrix\n");}
 	for (k = 0; k < J; k++) {
 	  detCurr += 2.0 * log(C[k*J+k]);
 	} // k
 	F77_NAME(dpotri)(lower, &J, C, &J, &info FCONE); 
-	if(info != 0){error("c++ error: Cholesky inverse failed in covariance matrix\n");}
+	if(info != 0){Rf_error("c++ error: Cholesky inverse failed in covariance matrix\n");}
         logPostCurr = 0.0; 
 	logPostCurr += log(phi - phiA) + log(phiB - phi); 
 	// (-1/2) * tmp_JD` *  C^-1 * tmp_JD
@@ -589,15 +590,15 @@ extern "C" {
 
         // Cholesky of A.w
         F77_NAME(dpotrf)(lower, &J, tmp_JJ, &J, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf on A.w failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf on A.w failed\n");}
 	// Inverse of A.w
         F77_NAME(dpotri)(lower, &J, tmp_JJ, &J, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri on A.w failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotri on A.w failed\n");}
         // A.w.inv %*% b.w. Stored in tmp_JD2
         F77_NAME(dsymv)(lower, &J, &one, tmp_JJ, &J, tmp_JD, &inc, &zero, tmp_JD2, &inc FCONE);
         // Computes cholesky of tmp_JJ again stored back in tmp_JJ. This chol(A.beta.inv)
         F77_NAME(dpotrf)(lower, &J, tmp_JJ, &J, &info FCONE); 
-	if(info != 0){error("c++ error: dpotrf on A.w failed\n");}
+	if(info != 0){Rf_error("c++ error: dpotrf on A.w failed\n");}
         // Args: destination, mu, cholesky of the covariance matrix, dimension
         mvrnorm(w, tmp_JD2, tmp_JJ, J);
 
@@ -698,8 +699,8 @@ extern "C" {
     SEXP result_r, resultName_r;
     int nResultListObjs = 8;
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     // Setting the components of the output list.
     SET_VECTOR_ELT(result_r, 0, betaSamples_r);
@@ -710,18 +711,18 @@ extern "C" {
     SET_VECTOR_ELT(result_r, 5, wSamples_r); 
     SET_VECTOR_ELT(result_r, 6, tuningSamples_r); 
     SET_VECTOR_ELT(result_r, 7, acceptSamples_r); 
-    // mkChar turns a C string into a CHARSXP
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("alpha.samples")); 
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("z.samples")); 
-    SET_VECTOR_ELT(resultName_r, 3, mkChar("psi.samples"));
-    SET_VECTOR_ELT(resultName_r, 4, mkChar("theta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 5, mkChar("w.samples")); 
-    SET_VECTOR_ELT(resultName_r, 6, mkChar("phi.tune")); 
-    SET_VECTOR_ELT(resultName_r, 7, mkChar("phi.accept")); 
+    // Rf_mkChar turns a C string into a CHARSXP
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("alpha.samples")); 
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("z.samples")); 
+    SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("psi.samples"));
+    SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("theta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("w.samples")); 
+    SET_VECTOR_ELT(resultName_r, 6, Rf_mkChar("phi.tune")); 
+    SET_VECTOR_ELT(resultName_r, 7, Rf_mkChar("phi.accept")); 
    
     // Set the names of the output list.  
-    namesgets(result_r, resultName_r);
+    Rf_namesgets(result_r, resultName_r);
     
     //unprotect
     UNPROTECT(nProtect);
