@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -48,8 +49,8 @@ void updateBFSVCTBin(double *B, double *F, double *c, double *C, double *coords,
 	    C[mm*threadID+l*nnIndxLU[n+i]+k] = sigmaSq*spCor(e, phi, nu, covModel, &bk[threadID*nb]);
 	  }
 	}
-	F77_NAME(dpotrf)(&lower, &nnIndxLU[n+i], &C[mm*threadID], &nnIndxLU[n+i], &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
-	F77_NAME(dpotri)(&lower, &nnIndxLU[n+i], &C[mm*threadID], &nnIndxLU[n+i], &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
+	F77_NAME(dpotrf)(&lower, &nnIndxLU[n+i], &C[mm*threadID], &nnIndxLU[n+i], &info FCONE); if(info != 0){Rf_error("c++ error: dpotrf failed\n");}
+	F77_NAME(dpotri)(&lower, &nnIndxLU[n+i], &C[mm*threadID], &nnIndxLU[n+i], &info FCONE); if(info != 0){Rf_error("c++ error: dpotri failed\n");}
 	F77_NAME(dsymv)(&lower, &nnIndxLU[n+i], &one, &C[mm*threadID], &nnIndxLU[n+i], &c[m*threadID], &inc, &zero, &B[nnIndxLU[i]], &inc FCONE);
 	F[i] = sigmaSq - F77_NAME(ddot)(&nnIndxLU[n+i], &B[nnIndxLU[i]], &inc, &c[m*threadID], &inc);
       }else{
@@ -170,7 +171,7 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
+      Rf_warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
       nThreads = 1;
     }
 #endif
@@ -245,34 +246,34 @@ extern "C" {
      * Return Stuff
      * *******************************************************************/
     SEXP betaSamples_r;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, p, nPost)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, p, nPost)); nProtect++;
     zeros(REAL(betaSamples_r), p * nPost);
     SEXP yRepSamples_r; 
-    PROTECT(yRepSamples_r = allocMatrix(REALSXP, JnYears, nPost)); nProtect++; 
+    PROTECT(yRepSamples_r = Rf_allocMatrix(REALSXP, JnYears, nPost)); nProtect++; 
     zeros(REAL(yRepSamples_r), JnYears * nPost);
     SEXP wSamples_r; 
-    PROTECT(wSamples_r = allocMatrix(REALSXP, JpTilde, nPost)); nProtect++; 
+    PROTECT(wSamples_r = Rf_allocMatrix(REALSXP, JpTilde, nPost)); nProtect++; 
     zeros(REAL(wSamples_r), JpTilde * nPost);
     SEXP psiSamples_r; 
-    PROTECT(psiSamples_r = allocMatrix(REALSXP, JnYears, nPost)); nProtect++; 
+    PROTECT(psiSamples_r = Rf_allocMatrix(REALSXP, JnYears, nPost)); nProtect++; 
     zeros(REAL(psiSamples_r), JnYears * nPost);
     // Occurrence random effects
     SEXP sigmaSqPsiSamples_r; 
     SEXP betaStarSamples_r; 
     if (pRE > 0) {
-      PROTECT(sigmaSqPsiSamples_r = allocMatrix(REALSXP, pRE, nPost)); nProtect++;
+      PROTECT(sigmaSqPsiSamples_r = Rf_allocMatrix(REALSXP, pRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqPsiSamples_r), pRE * nPost);
-      PROTECT(betaStarSamples_r = allocMatrix(REALSXP, nRE, nPost)); nProtect++;
+      PROTECT(betaStarSamples_r = Rf_allocMatrix(REALSXP, nRE, nPost)); nProtect++;
       zeros(REAL(betaStarSamples_r), nRE * nPost);
     }
     // Likelihood samples for WAIC. 
     SEXP likeSamples_r;
-    PROTECT(likeSamples_r = allocMatrix(REALSXP, JnYears, nPost)); nProtect++;
+    PROTECT(likeSamples_r = Rf_allocMatrix(REALSXP, JnYears, nPost)); nProtect++;
     zeros(REAL(likeSamples_r), JnYears * nPost);
     // AR(1) stuff. 
     SEXP etaSamples_r; 
     if (ar1) {
-      PROTECT(etaSamples_r = allocMatrix(REALSXP, nYearsMax, nPost)); nProtect++; 
+      PROTECT(etaSamples_r = Rf_allocMatrix(REALSXP, nYearsMax, nPost)); nProtect++; 
       zeros(REAL(etaSamples_r), nYearsMax * nPost);
     }
     
@@ -314,9 +315,9 @@ extern "C" {
     // For normal priors
     // Occupancy regression coefficient priors. 
     F77_NAME(dpotrf)(lower, &p, SigmaBetaInv, &p, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf SigmaBetaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf SigmaBetaInv failed\n");}
     F77_NAME(dpotri)(lower, &p, SigmaBetaInv, &p, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri SigmaBetaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri SigmaBetaInv failed\n");}
     double *SigmaBetaInvMuBeta = (double *) R_alloc(p, sizeof(double)); 
     F77_NAME(dsymv)(lower, &p, &one, SigmaBetaInv, &p, muBeta, &inc, &zero, 
         	    SigmaBetaInvMuBeta, &inc FCONE);
@@ -368,13 +369,13 @@ extern "C" {
     double logDet;  
     double phiCand = 0.0, nuCand = 0.0, rhoCand = 0.0, sigmaSqCand = 0.0;  
     SEXP acceptSamples_r; 
-    PROTECT(acceptSamples_r = allocMatrix(REALSXP, nThetaAll, nBatch)); nProtect++; 
+    PROTECT(acceptSamples_r = Rf_allocMatrix(REALSXP, nThetaAll, nBatch)); nProtect++; 
     zeros(REAL(acceptSamples_r), nThetaAll * nBatch);
     SEXP tuningSamples_r; 
-    PROTECT(tuningSamples_r = allocMatrix(REALSXP, nThetaAll, nBatch)); nProtect++; 
+    PROTECT(tuningSamples_r = Rf_allocMatrix(REALSXP, nThetaAll, nBatch)); nProtect++; 
     zeros(REAL(tuningSamples_r), nThetaAll * nBatch);
     SEXP thetaSamples_r; 
-    PROTECT(thetaSamples_r = allocMatrix(REALSXP, nThetaAll, nPost)); nProtect++; 
+    PROTECT(thetaSamples_r = Rf_allocMatrix(REALSXP, nThetaAll, nPost)); nProtect++; 
     zeros(REAL(thetaSamples_r), nThetaAll * nPost);
     double b, e, aij, aa; 
     double *a = (double *) R_alloc(pTilde, sizeof(double));
@@ -440,9 +441,9 @@ extern "C" {
       AR1(nYearsMax, theta[rhoIndx], theta[sigmaSqTIndx], SigmaEta);
       clearUT(SigmaEta, nYearsMax);
       F77_NAME(dpotrf)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-      if(info != 0){error("c++ error: Cholesky failed in initial AR(1) covariance matrix\n");}
+      if(info != 0){Rf_error("c++ error: Cholesky failed in initial AR(1) covariance matrix\n");}
       F77_NAME(dpotri)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-      if(info != 0){error("c++ error: Cholesky inverse failed in initial AR(1) covariance matrix\n");}
+      if(info != 0){Rf_error("c++ error: Cholesky inverse failed in initial AR(1) covariance matrix\n");}
     }
     double *eta = (double *) R_alloc(nYearsMax, sizeof(double)); zeros(eta, nYearsMax);
     // For sigmaSqT sampler
@@ -524,12 +525,12 @@ extern "C" {
 
 
         F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf A.beta failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf A.beta failed\n");}
         F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri A.beta failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotri A.beta failed\n");}
         F77_NAME(dsymv)(lower, &p, &one, tmp_pp, &p, tmp_p, &inc, &zero, tmp_p2, &inc FCONE);
         F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); 
-	if(info != 0){error("c++ error: dpotrf A.beta2 failed\n");}
+	if(info != 0){Rf_error("c++ error: dpotrf A.beta2 failed\n");}
         mvrnorm(beta, tmp_p2, tmp_pp, p);
 
         /********************************************************************
@@ -635,9 +636,9 @@ extern "C" {
             var[k * pTilde + k] += ff[k] + v[k]; 
           } // k
 	  F77_NAME(dpotrf)(lower, &pTilde, var, &pTilde, &info FCONE);
-          if(info != 0){error("c++ error: dpotrf var failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf var failed\n");}
 	  F77_NAME(dpotri)(lower, &pTilde, var, &pTilde, &info FCONE);
-          if(info != 0){error("c++ error: dpotri var failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotri var failed\n");}
 
 	  // mu
 	  for (k = 0; k < pTilde; k++) {
@@ -652,7 +653,7 @@ extern "C" {
 	  F77_NAME(dsymv)(lower, &pTilde, &one, var, &pTilde, mu, &inc, &zero, tmp_pTilde, &inc FCONE);
 
 	  F77_NAME(dpotrf)(lower, &pTilde, var, &pTilde, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf var 2 failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf var 2 failed\n");}
 
 	  mvrnorm(&w[ii * pTilde], tmp_pTilde, var, pTilde);
         } // ii (site)
@@ -805,9 +806,9 @@ extern "C" {
           AR1(nYearsMax, theta[rhoIndx], 1.0, SigmaEta);
 	  clearUT(SigmaEta, nYearsMax);
 	  F77_NAME(dpotrf)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky failed in covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky failed in covariance matrix\n");}
 	  F77_NAME(dpotri)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky inverse failed in covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky inverse failed in covariance matrix\n");}
 	  fillUTri(SigmaEta, nYearsMax);
 	  // Compute t(eta) %*% SigmaEta^-1 %*% eta
           for (t = 0; t < nYearsMax; t++) {
@@ -836,13 +837,13 @@ extern "C" {
 	  // Invert SigmaEtaCand and log det cov. 
           logPostCand = 0.0;
 	  F77_NAME(dpotrf)(lower, &nYearsMax, SigmaEtaCand, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky failed in proposal covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky failed in proposal covariance matrix\n");}
 	  // Get log of the determinant of the covariance matrix. 
 	  for (k = 0; k < nYearsMax; k++) {
 	    logPostCand += 2.0 * log(SigmaEtaCand[k*nYearsMax+k]);
 	  } // k
 	  F77_NAME(dpotri)(lower, &nYearsMax, SigmaEtaCand, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky inverse failed in proposal covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky inverse failed in proposal covariance matrix\n");}
           logPostCand = 0.0; 
 	  // Jacobian and Uniform prior. 
 	  logPostCand += log(rhoCand - rhoA) + log(rhoB - rhoCand); 
@@ -856,12 +857,12 @@ extern "C" {
 	  clearUT(SigmaEta, nYearsMax);
           logPostCurr = 0.0;
 	  F77_NAME(dpotrf)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky failed in covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky failed in covariance matrix\n");}
 	  for (k = 0; k < nYearsMax; k++) {
 	    logPostCurr += 2.0 * log(SigmaEta[k*nYearsMax+k]);
 	  } // k
 	  F77_NAME(dpotri)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky inverse failed in covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky inverse failed in covariance matrix\n");}
           logPostCurr = 0.0; 
 	  logPostCurr += log(rho - rhoA) + log(rhoB - rho); 
 	  // (-1/2) * tmp_JD` *  C^-1 * tmp_JD
@@ -904,15 +905,15 @@ extern "C" {
 
           // Cholesky of A.eta
           F77_NAME(dpotrf)(lower, &nYearsMax, tmp_nnYears, &nYearsMax, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf on A.eta failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf on A.eta failed\n");}
 	  // Inverse of A.eta
           F77_NAME(dpotri)(lower, &nYearsMax, tmp_nnYears, &nYearsMax, &info FCONE); 
-          if(info != 0){error("c++ error: dpotri on A.eta failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotri on A.eta failed\n");}
           // A.eta.inv %*% b.eta. Stored in tmp_
           F77_NAME(dsymv)(lower, &nYearsMax, &one, tmp_nnYears, &nYearsMax, 
 	  		tmp_nYearsMax, &inc, &zero, tmp_nYearsMax2, &inc FCONE);
           F77_NAME(dpotrf)(lower, &nYearsMax, tmp_nnYears, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: dpotrf on A.eta failed\n");}
+	  if(info != 0){Rf_error("c++ error: dpotrf on A.eta failed\n");}
           // Args: destination, mu, cholesky of the covariance matrix, dimension
           mvrnorm(eta, tmp_nYearsMax2, tmp_nnYears, nYearsMax);
 	}
@@ -1024,8 +1025,8 @@ extern "C" {
       nResultListObjs += 1;
     }
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     // Setting the components of the output list.
     SET_VECTOR_ELT(result_r, 0, betaSamples_r);
@@ -1049,25 +1050,25 @@ extern "C" {
       SET_VECTOR_ELT(result_r, tmp_0, etaSamples_r);
     }    
 
-    // mkChar turns a C string into a CHARSXP
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("y.rep.samples")); 
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("psi.samples"));
-    SET_VECTOR_ELT(resultName_r, 3, mkChar("theta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 4, mkChar("w.samples")); 
-    SET_VECTOR_ELT(resultName_r, 5, mkChar("tune")); 
-    SET_VECTOR_ELT(resultName_r, 6, mkChar("accept")); 
-    SET_VECTOR_ELT(resultName_r, 7, mkChar("like.samples")); 
+    // Rf_mkChar turns a C string into a CHARSXP
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("y.rep.samples")); 
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("psi.samples"));
+    SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("theta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("w.samples")); 
+    SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("tune")); 
+    SET_VECTOR_ELT(resultName_r, 6, Rf_mkChar("accept")); 
+    SET_VECTOR_ELT(resultName_r, 7, Rf_mkChar("like.samples")); 
     if (pRE > 0) {
-      SET_VECTOR_ELT(resultName_r, 8, mkChar("sigma.sq.psi.samples")); 
-      SET_VECTOR_ELT(resultName_r, 9, mkChar("beta.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, 8, Rf_mkChar("sigma.sq.psi.samples")); 
+      SET_VECTOR_ELT(resultName_r, 9, Rf_mkChar("beta.star.samples")); 
     }
     if (ar1) {
-      SET_VECTOR_ELT(resultName_r, tmp_0, mkChar("eta.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_0, Rf_mkChar("eta.samples")); 
     }
     
     // Set the names of the output list.  
-    namesgets(result_r, resultName_r);
+    Rf_namesgets(result_r, resultName_r);
     
     //unprotect
     UNPROTECT(nProtect);
