@@ -7,6 +7,7 @@
 #include <omp.h>
 #endif
 
+#define R_NO_REMAP
 #include <R.h>
 #include <Rmath.h>
 #include <Rinternals.h>
@@ -124,7 +125,7 @@ extern "C" {
     omp_set_num_threads(nThreads);
 #else
     if(nThreads > 1){
-      warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
+      Rf_warning("n.omp.threads > %i, but source not compiled with OpenMP support.", nThreads);
       nThreads = 1;
     }
 #endif
@@ -195,43 +196,43 @@ extern "C" {
      * Return Stuff
      * *******************************************************************/
     SEXP betaSamples_r;
-    PROTECT(betaSamples_r = allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
+    PROTECT(betaSamples_r = Rf_allocMatrix(REALSXP, pOcc, nPost)); nProtect++;
     zeros(REAL(betaSamples_r), pOcc * nPost);
     SEXP alphaSamples_r; 
-    PROTECT(alphaSamples_r = allocMatrix(REALSXP, pDet, nPost)); nProtect++;
+    PROTECT(alphaSamples_r = Rf_allocMatrix(REALSXP, pDet, nPost)); nProtect++;
     zeros(REAL(alphaSamples_r), pDet * nPost);
     SEXP zSamples_r; 
-    PROTECT(zSamples_r = allocMatrix(REALSXP, JnYears, nPost)); nProtect++; 
+    PROTECT(zSamples_r = Rf_allocMatrix(REALSXP, JnYears, nPost)); nProtect++; 
     zeros(REAL(zSamples_r), JnYears * nPost);
     SEXP etaSamples_r; 
     if (ar1) {
-      PROTECT(etaSamples_r = allocMatrix(REALSXP, nYearsMax, nPost)); nProtect++; 
+      PROTECT(etaSamples_r = Rf_allocMatrix(REALSXP, nYearsMax, nPost)); nProtect++; 
       zeros(REAL(etaSamples_r), nYearsMax * nPost);
     }
     SEXP psiSamples_r; 
-    PROTECT(psiSamples_r = allocMatrix(REALSXP, JnYears, nPost)); nProtect++; 
+    PROTECT(psiSamples_r = Rf_allocMatrix(REALSXP, JnYears, nPost)); nProtect++; 
     zeros(REAL(psiSamples_r), JnYears * nPost);
     // Detection random effects
     SEXP sigmaSqPSamples_r; 
     SEXP alphaStarSamples_r; 
     if (pDetRE > 0) {
-      PROTECT(sigmaSqPSamples_r = allocMatrix(REALSXP, pDetRE, nPost)); nProtect++;
+      PROTECT(sigmaSqPSamples_r = Rf_allocMatrix(REALSXP, pDetRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqPSamples_r), pDetRE * nPost);
-      PROTECT(alphaStarSamples_r = allocMatrix(REALSXP, nDetRE, nPost)); nProtect++;
+      PROTECT(alphaStarSamples_r = Rf_allocMatrix(REALSXP, nDetRE, nPost)); nProtect++;
       zeros(REAL(alphaStarSamples_r), nDetRE * nPost);
     }
     // Occurrence random effects
     SEXP sigmaSqPsiSamples_r; 
     SEXP betaStarSamples_r; 
     if (pOccRE > 0) {
-      PROTECT(sigmaSqPsiSamples_r = allocMatrix(REALSXP, pOccRE, nPost)); nProtect++;
+      PROTECT(sigmaSqPsiSamples_r = Rf_allocMatrix(REALSXP, pOccRE, nPost)); nProtect++;
       zeros(REAL(sigmaSqPsiSamples_r), pOccRE * nPost);
-      PROTECT(betaStarSamples_r = allocMatrix(REALSXP, nOccRE, nPost)); nProtect++;
+      PROTECT(betaStarSamples_r = Rf_allocMatrix(REALSXP, nOccRE, nPost)); nProtect++;
       zeros(REAL(betaStarSamples_r), nOccRE * nPost);
     }
     // Likelihood samples for WAIC. 
     SEXP likeSamples_r;
-    PROTECT(likeSamples_r = allocMatrix(REALSXP, JnYears, nPost)); nProtect++;
+    PROTECT(likeSamples_r = Rf_allocMatrix(REALSXP, JnYears, nPost)); nProtect++;
     zeros(REAL(likeSamples_r), J * nPost);
     
     /**********************************************************************
@@ -281,17 +282,17 @@ extern "C" {
     // For normal priors
     // Occupancy regression coefficient priors. 
     F77_NAME(dpotrf)(lower, &pOcc, SigmaBetaInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf SigmaBetaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf SigmaBetaInv failed\n");}
     F77_NAME(dpotri)(lower, &pOcc, SigmaBetaInv, &pOcc, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri SigmaBetaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri SigmaBetaInv failed\n");}
     double *SigmaBetaInvMuBeta = (double *) R_alloc(pOcc, sizeof(double)); 
     F77_NAME(dsymv)(lower, &pOcc, &one, SigmaBetaInv, &pOcc, muBeta, &inc, &zero, 
         	    SigmaBetaInvMuBeta, &inc FCONE);
     // Detection regression coefficient priors. 
     F77_NAME(dpotrf)(lower, &pDet, SigmaAlphaInv, &pDet, &info FCONE); 
-    if(info != 0){error("c++ error: dpotrf SigmaAlphaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotrf SigmaAlphaInv failed\n");}
     F77_NAME(dpotri)(lower, &pDet, SigmaAlphaInv, &pDet, &info FCONE); 
-    if(info != 0){error("c++ error: dpotri SigmaAlphaInv failed\n");}
+    if(info != 0){Rf_error("c++ error: dpotri SigmaAlphaInv failed\n");}
     double *SigmaAlphaInvMuAlpha = (double *) R_alloc(pDet, sizeof(double)); 
     F77_NAME(dsymv)(lower, &pDet, &one, SigmaAlphaInv, &pDet, muAlpha, &inc, &zero, 
                    SigmaAlphaInvMuAlpha, &inc FCONE);
@@ -348,7 +349,7 @@ extern "C" {
     double rhoCand = 0.0; 
     SEXP thetaSamples_r; 
     if (ar1) {
-      PROTECT(thetaSamples_r = allocMatrix(REALSXP, nTheta, nPost)); nProtect++; 
+      PROTECT(thetaSamples_r = Rf_allocMatrix(REALSXP, nTheta, nPost)); nProtect++; 
       zeros(REAL(thetaSamples_r), nTheta * nPost);
     }
     // Initiate values
@@ -365,9 +366,9 @@ extern "C" {
       // expCov(nYearsMax, theta[rhoIndx], theta[sigmaSqTIndx], SigmaEta);
       clearUT(SigmaEta, nYearsMax);
       F77_NAME(dpotrf)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-      if(info != 0){error("c++ error: Cholesky failed in initial time covariance matrix\n");}
+      if(info != 0){Rf_error("c++ error: Cholesky failed in initial time covariance matrix\n");}
       F77_NAME(dpotri)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-      if(info != 0){error("c++ error: Cholesky inverse failed in initial time covariance matrix\n");}
+      if(info != 0){Rf_error("c++ error: Cholesky inverse failed in initial time covariance matrix\n");}
     }
     double *eta = (double *) R_alloc(nYearsMax, sizeof(double)); zeros(eta, nYearsMax);
     // For sigmaSqT sampler
@@ -466,12 +467,12 @@ extern "C" {
 
 
         F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf A.beta failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf A.beta failed\n");}
         F77_NAME(dpotri)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri A.beta failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotri A.beta failed\n");}
         F77_NAME(dsymv)(lower, &pOcc, &one, tmp_ppOcc, &pOcc, tmp_pOcc, &inc, &zero, tmp_pOcc2, &inc FCONE);
         F77_NAME(dpotrf)(lower, &pOcc, tmp_ppOcc, &pOcc, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf A.beta2 failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf A.beta2 failed\n");}
         mvrnorm(beta, tmp_pOcc2, tmp_ppOcc, pOcc);
 
         /********************************************************************
@@ -513,12 +514,12 @@ extern "C" {
         } // j
 
         F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf A.alpha failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf A.alpha failed\n");}
         F77_NAME(dpotri)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-        if(info != 0){error("c++ error: dpotri A.alpha failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotri A.alpha failed\n");}
         F77_NAME(dsymv)(lower, &pDet, &one, tmp_ppDet, &pDet, tmp_pDet, &inc, &zero, tmp_pDet2, &inc FCONE);
         F77_NAME(dpotrf)(lower, &pDet, tmp_ppDet, &pDet, &info FCONE); 
-        if(info != 0){error("c++ error: dpotrf here failed\n");}
+        if(info != 0){Rf_error("c++ error: dpotrf here failed\n");}
         mvrnorm(alpha, tmp_pDet2, tmp_ppDet, pDet);
 
         /********************************************************************
@@ -633,9 +634,9 @@ extern "C" {
           // expCov(nYearsMax, theta[rhoIndx], 1.0, SigmaEta);
 	  clearUT(SigmaEta, nYearsMax);
 	  F77_NAME(dpotrf)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky failed in covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky failed in covariance matrix\n");}
 	  F77_NAME(dpotri)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky inverse failed in covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky inverse failed in covariance matrix\n");}
 	  fillUTri(SigmaEta, nYearsMax);
 	  // Compute t(eta) %*% SigmaEta^-1 %*% eta
           for (t = 0; t < nYearsMax; t++) {
@@ -665,13 +666,13 @@ extern "C" {
 	  // Invert SigmaEtaCand and log det cov. 
           detCand = 0.0;
 	  F77_NAME(dpotrf)(lower, &nYearsMax, SigmaEtaCand, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky failed in proposal covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky failed in proposal covariance matrix\n");}
 	  // Get log of the determinant of the covariance matrix. 
 	  for (k = 0; k < nYearsMax; k++) {
 	    detCand += 2.0 * log(SigmaEtaCand[k*nYearsMax+k]);
 	  } // k
 	  F77_NAME(dpotri)(lower, &nYearsMax, SigmaEtaCand, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky inverse failed in proposal covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky inverse failed in proposal covariance matrix\n");}
           logPostCand = 0.0; 
 	  // Jacobian and Uniform prior. 
 	  logPostCand += log(rhoCand - rhoA) + log(rhoB - rhoCand); 
@@ -686,12 +687,12 @@ extern "C" {
 	  clearUT(SigmaEta, nYearsMax);
           detCurr = 0.0;
 	  F77_NAME(dpotrf)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky failed in covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky failed in covariance matrix\n");}
 	  for (k = 0; k < nYearsMax; k++) {
 	    detCurr += 2.0 * log(SigmaEta[k*nYearsMax+k]);
 	  } // k
 	  F77_NAME(dpotri)(lower, &nYearsMax, SigmaEta, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: Cholesky inverse failed in covariance matrix\n");}
+	  if(info != 0){Rf_error("c++ error: Cholesky inverse failed in covariance matrix\n");}
           logPostCurr = 0.0; 
 	  logPostCurr += log(rho - rhoA) + log(rhoB - rho); 
 	  // (-1/2) * tmp_JD` *  C^-1 * tmp_JD
@@ -736,15 +737,15 @@ extern "C" {
 
           // Cholesky of A.eta
           F77_NAME(dpotrf)(lower, &nYearsMax, tmp_nnYears, &nYearsMax, &info FCONE); 
-          if(info != 0){error("c++ error: dpotrf on A.eta failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotrf on A.eta failed\n");}
 	  // Inverse of A.eta
           F77_NAME(dpotri)(lower, &nYearsMax, tmp_nnYears, &nYearsMax, &info FCONE); 
-          if(info != 0){error("c++ error: dpotri on A.eta failed\n");}
+          if(info != 0){Rf_error("c++ error: dpotri on A.eta failed\n");}
           // A.eta.inv %*% b.eta. Stored in tmp_
           F77_NAME(dsymv)(lower, &nYearsMax, &one, tmp_nnYears, &nYearsMax, 
 	  		tmp_nYearsMax, &inc, &zero, tmp_nYearsMax2, &inc FCONE);
           F77_NAME(dpotrf)(lower, &nYearsMax, tmp_nnYears, &nYearsMax, &info FCONE); 
-	  if(info != 0){error("c++ error: dpotrf on A.eta failed\n");}
+	  if(info != 0){Rf_error("c++ error: dpotrf on A.eta failed\n");}
           // Args: destination, mu, cholesky of the covariance matrix, dimension
           mvrnorm(eta, tmp_nYearsMax2, tmp_nnYears, nYearsMax);
 	}
@@ -877,8 +878,8 @@ extern "C" {
       nResultListObjs += 2;
     }
 
-    PROTECT(result_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
-    PROTECT(resultName_r = allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(result_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
+    PROTECT(resultName_r = Rf_allocVector(VECSXP, nResultListObjs)); nProtect++;
 
     // Setting the components of the output list.
     SET_VECTOR_ELT(result_r, 0, betaSamples_r);
@@ -912,27 +913,27 @@ extern "C" {
       SET_VECTOR_ELT(result_r, ar1Ind + 1, thetaSamples_r);
     }
 
-    SET_VECTOR_ELT(resultName_r, 0, mkChar("beta.samples")); 
-    SET_VECTOR_ELT(resultName_r, 1, mkChar("alpha.samples")); 
-    SET_VECTOR_ELT(resultName_r, 2, mkChar("z.samples")); 
-    SET_VECTOR_ELT(resultName_r, 3, mkChar("psi.samples"));
-    SET_VECTOR_ELT(resultName_r, 4, mkChar("like.samples"));
+    SET_VECTOR_ELT(resultName_r, 0, Rf_mkChar("beta.samples")); 
+    SET_VECTOR_ELT(resultName_r, 1, Rf_mkChar("alpha.samples")); 
+    SET_VECTOR_ELT(resultName_r, 2, Rf_mkChar("z.samples")); 
+    SET_VECTOR_ELT(resultName_r, 3, Rf_mkChar("psi.samples"));
+    SET_VECTOR_ELT(resultName_r, 4, Rf_mkChar("like.samples"));
     if (pDetRE > 0) {
-      SET_VECTOR_ELT(resultName_r, 5, mkChar("sigma.sq.p.samples")); 
-      SET_VECTOR_ELT(resultName_r, 6, mkChar("alpha.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, 5, Rf_mkChar("sigma.sq.p.samples")); 
+      SET_VECTOR_ELT(resultName_r, 6, Rf_mkChar("alpha.star.samples")); 
     }
     if (pOccRE > 0) {
-      SET_VECTOR_ELT(resultName_r, tmp_0, mkChar("sigma.sq.psi.samples")); 
-      SET_VECTOR_ELT(resultName_r, tmp_0 + 1, mkChar("beta.star.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_0, Rf_mkChar("sigma.sq.psi.samples")); 
+      SET_VECTOR_ELT(resultName_r, tmp_0 + 1, Rf_mkChar("beta.star.samples")); 
     }
     if (ar1) {
-      SET_VECTOR_ELT(resultName_r, ar1Ind, mkChar("eta.samples")); 
-      SET_VECTOR_ELT(resultName_r, ar1Ind + 1, mkChar("theta.samples")); 
+      SET_VECTOR_ELT(resultName_r, ar1Ind, Rf_mkChar("eta.samples")); 
+      SET_VECTOR_ELT(resultName_r, ar1Ind + 1, Rf_mkChar("theta.samples")); 
 
     }
     
     // Set the names of the output list.  
-    namesgets(result_r, resultName_r);
+    Rf_namesgets(result_r, resultName_r);
     
     //unprotect
     UNPROTECT(nProtect);
